##########################################################################
# Package Definitions #
##########################################################################
# Subver for branch/trunk tracking (cleared with each svn bump), and real version for normal builds
  %global			subVer		1


# SELinux support (default: yes)
  %bcond_without		selinux

# Use /dev/shm as client's tmp directory (default: yes)
  %bcond_without		clientshmtmp

# http://fedoraproject.org/wiki/Packaging:Guidelines#PIE
  %define			_hardened_build 1

# Systemd build (default: yes on Fedora18+/RHEL7+)
  %if 0%{?fedora} >= 18
	%define	_with_systemd	--with-systemd
	%define	_with_httpd24	--with-httpd24
  %endif
  %if 0%{?rhel} >= 7
	%define	_with_systemd	--with-systemd
	%define	_with_httpd24	--with-httpd24
  %endif

# Use alternate execution shell? (default: no)
  %bcond_with			altshell
  %global			shell	/bin/dash

  %bcond_with			systemd
  %bcond_with			httpd24


# Build trunk version (default: no)
  %bcond_with			trunk
  %if %{with trunk}
  # If you're building --with trunk, we expect an svn directory at the location below. The "trunk version"
  # is used when looking for a tarball in SOURCES, and when building the eventual RPM.
  # %define			trunkVersion	%(svn info ~/svn/xymon/trunk/ | grep ^Revision | awk '{print $2}')
  # %define			trunkVersion	7344
  %endif

# Build branch version (default: no)
  %bcond_with			branch
  %global			branchVer	4.3.14
  %if %{with branch}
  # If you're building --with branch, we still need a trunk version to base this off of. We expect a tarball named:
  # xymon-{branchversion}-0.{trunkversion}.tar.gz in SOURCES
  # %define			trunkVersion	%(svn info ~/svn/xymon/trunk/ | grep ^Revision | awk '{print $2}')
  # %define			trunkVersion	7344
  %endif


# client needs to be able to read /var/log/messages. File ACLs are the best 
# way to do this, but logwatch blows them away on rotation (BZ#666677, 
# 683622, and 683626). Until then, chgrp adm /var/log/messages and make that
# one of xymon's secondary groups. (default: yes)
  %bcond_without		logreader
  %define	logReaderGroup	adm

# Use file ACLs to give xymon user read privs on logs? (default: yes)
  %bcond_without		facl

# Experimental native snmp support (default: yes)
  %bcond_without		snmp


# Build an additional static-compiled client RPM? (default: no, as of 4.3.13)
  %bcond_with			dietlibc

# Build orcamon and reduced-functionality client RPMs (default: no)
  %bcond_with			extraclients

# Build with additional, experimental features (default: no)
  %bcond_with			bleeding


##########################################################################
# Headers #
##########################################################################
%define serverName	xymon
%define clientName	xymon-client
%define xymonRoot	%{_datadir}/xymon
%define xymonServerRoot	%{_datadir}/%{serverName}
%define xymonClientRoot	%{_datadir}/%{clientName}

Name:		xymon
Summary:	A system for monitoring servers and networks
Group:		Applications/System
License:	GPLv2
URL:		http://xymon.sourceforge.net/

%if %{without trunk}
%if %{without branch}
### Build Regular Version ###
Version:	4.3.13
Release:	%{subVer}%{?dist}
Source0:	http://prdownloads.sourceforge.net/xymon/%{name}-%{version}.tar.gz


%else
### Build Branch Version ###
Version:	%{branchVer}
Release:	0.%{trunkVersion}.%{subVer}%{?dist}
Source0:	http://prdownloads.sourceforge.net/xymon/%{name}-%{version}-0.%{trunkVersion}.tar.gz
%endif


%else
### Build Trunk Version ###
Version:	0.%{trunkVersion}
Release:	%{subVer}%{?dist}
Source0:	xymon-trunk-%{trunkVersion}.tgz
%endif



# Updated init scripts
Source1:	xymon.server-init
Source2:	xymon.client-init
Source3:	xymonlaunch.default
Source4:	xymon-client.default
Source5:	xymon.README.terabithia
Source6:	xymon.CHANGES.terabithia
Source7:	xymon430.README.core
Source8:	xymonlaunch.service
Source9:	xymoncgimsg.conf
Source10:	xymonlaunch.service.preset

# Use updated version of c-ares even outside of trunk
%define		caresVer	1.10.0
Source11:	http://c-ares.haxx.se/download/c-ares-%{caresVer}.tar.gz

# Use a current version of sqlite if building with trunk,
# since RHEL5 and below uses a version that's too old by default
%define		sqliteVer	3080200
Source12:	http://www.sqlite.org/2013/sqlite-amalgamation-%{sqliteVer}.zip

%define		md5Ver		2002-04-13
Source13:	http://prdownloads.sourceforge.net/libmd5-rfc/libmd5-rfc/%{md5Ver}/md5.tar.gz



# Drop-in additions to the local client
Source21:	xymon.sections.mounts
Source22:	xymon.sections.meminfo
Source23:	xymon.sections.vmstats
Source24:	xymon.sections.ipcs

# xymonlaunch task files for periodic report generation
Source31:	xymonreports.daily.task
Source32:	xymonreports.weekly.task
Source33:	xymonreports.monthly.task

# SELinux policy sources
Source41:	xymon.te
Source42:	xymon-client.te

# Some extra images for xymongen
Source51:	xymon.info.gif
Source52:	xymon.trends.gif
Source53:	xymon.client.gif

Source61:	xymon.logfetchupdate.sh
Source62:	xymon.logfetchupdate.cfg

BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires:	openssl-devel, pcre-devel, rrdtool-devel, openldap-devel
%if %{with trunk}
BuildRequires:	sqlite-devel >= 3, zlib-devel
%if %{with dietlibc}
BuildRequires:	zlib-static
# openssl-static is never going to work on stock RH/Fedora, sadly
# cf. BZ#807050, 838782
#BuildRequires:	openssl-static
%endif
%endif

# Provides:	xymon-client%{?_isa} = %{version}-%{release}, xymon-client-passive%{?_isa} = %{version}-%{release}, xymon-client-core%{?_isa} = %{version}-%{release}
Requires:	/usr/sbin/httpd logrotate fping
Requires(pre):	/usr/sbin/httpd
Requires(post):	perl

%if %{with selinux}
%global selinux_types %(%{__awk} '/^#[[:space:]]*SELINUXTYPE=/,/^[^#]/ { if ($3 == "-") printf "%s ", $2 }' /etc/selinux/config 2>/dev/null)
%global selinux_variants %([ -z "%{selinux_types}" ] && echo mls targeted || echo %{selinux_types})

# Very ugly, but the preferred hack from http://fedoraproject.org/wiki/SELinux_Policy_Modules_Packaging_Draft -- for RHEL and Fedora, up to an including 20
%{!?_selinux_policy_version: %global _selinux_policy_version %(sed -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp 2>/dev/null)}
%if "%{_selinux_policy_version}" != ""
Requires:      selinux-policy >= %{_selinux_policy_version}
%endif

BuildRequires:	checkpolicy, selinux-policy-devel, /usr/share/selinux/devel/policyhelp
Requires(post):		/usr/sbin/semodule, /usr/sbin/semanage, /sbin/restorecon
Requires(postun):	/usr/sbin/semodule, /usr/sbin/semanage
%endif

%if %{with systemd}
BuildRequires:	systemd
Requires(post):	systemd
Requires(preun):	systemd
Requires(postun):	systemd
%endif
%if %{without trunk}
Requires:	ntp
%endif
%if %{with altshell}
Requires:	%{shell}
%endif
%if %{with snmp}
BuildRequires:	net-snmp-devel
%endif
%if %{with dietlibc}
BuildRequires:	/usr/bin/diet
%endif


#################
# Patches	#
#################

# move static www files from HOME/www to HOME/static
Patch1: xymon_4313.installstaticwww.patch

# specify location of help files instead of assuming
Patch2: xymon.helpdir.patch

# create missing www/rep www/snap www/html www/notes directories if needed
# (for tmps wwwdir)
Patch45: xymon.mkdir.patch

# Move /periodic (xymonreports output) and /notes from the web tree
# to /var/lib/xymon/
Patch46: xymon.varlibwww.patch

# move pid files to rundir
# see: https://sourceforge.net/tracker/?func=detail&aid=3170854&group_id=128058&atid=710490
Patch303: xymon_trunk.rundir.patch
Patch3: xymon.rundir.patch

# Activate (has to be applied after launchlogging patch, below)
# send HUPs from xymonlaunch
Patch603: xymon.rundir-tasks.patch


# add a "sections" directory, for scripts whose output will automatically be included in the Xymon client data
# based on trunk: http://xymon.svn.sourceforge.net/viewvc/xymon?view=revision&sortby=rev&sortdir=down&revision=6800
# but w/o "local:" header
Patch4: xymon.sections.patch

# insert /etc/xymon/*.d/ references in config files
Patch5: xymon.breakout-directories.patch

# include init scripts in the regexes performed during 'make'
Patch6: xymon437.initdvars.patch

# remove auto-updating of scripts and binaries from xymonclient.sh
# since there's no good way to make this work on an RPM system
Patch8: xymon.noclientupdate.patch


# We don't package anything in /usr/local, but check there for
# local xymon-client script add-ins
Patch13: xymon.usrlocallocaldir.patch

# don't sleep after running xymonclient
Patch15: xymon.nosleep.patch


# macro-wrap dbgprintf
Patch17: xymon.debugmacro.patch

# xymond not following {net,disp}include lines properly
# see https://sourceforge.net/mailarchive/message.php?msg_id=28657398
Patch18: xymon.nullfollowsincl.patch



# allow http tests to store the raw output as a data message (data=)
#Patch27: xymon.datahttp.patch
Patch327: xymon_branch.datahttp.patch


# don't print default env file name unless running xymoncmd with --debug
# see: https://sourceforge.net/tracker/?func=detail&aid=3170846&group_id=128058&atid=710490
Patch30: xymon.quietcmd.patch

# XYMONCLIENTHOME was not being set on clients running xymoncmd
# see: https://sourceforge.net/tracker/?func=detail&aid=3170916&group_id=128058&atid=710490
Patch36: xymon.xymonclienthome.patch

# Create a channel for "metric" messages
#Patch38: xymon.metricchn.patch

# use environment variables if no args given to xymon client
Patch41: xymon.xymonmsg.patch

# prevent refresh loop when loading "trends" page when locator is enabled
Patch44: xymon.trendsloop.patch

# Have mercy on those who type /xymon instead of /xymon/
Patch47: xymon.dirredir.patch

# Try harder to send a xymon message when segfaulting
Patch48: xymon.sigbetter.patch

# Silence an rpmlint warning about packaging an empty file
Patch49: xymon.confreport_back.patch


# allow xymoncmd to be run without XYMONHOME env variable pre-set
Patch50: xymon.homelesscmd.patch

# point apache-writable /rep and /snap to /var/cache/xymon
Patch51: xymon.wwwcachedir.patch


# respect /etc/sysconfig/xymon-client as source of truth for 
# destination of local client reports (even on servers)
Patch52: xymon.alwaysmultiservers.patch
Patch53: xymon.usesysconfig.patch
Patch54: xymon.serverclient.patch

# More verbose logging from xymond in non-debug mode
Patch55: xymon.morexymondlogs.patch
Patch355: xymon_trunk.morexymondlogs.patch
Patch56: xymon.logprintf.patch

# Allow "source" and "." as synonyms for "include" (file only)
Patch59: xymon.shellinclude.patch

# Use unix timestamps instead of english dates for history logs
Patch60: xymon.epoch_histlogs.patch

# Reset failure count after x minutes, so xymonlaunch
# doesn't delay a relaunch because of issues weeks ago.
Patch61: xymon.resetfails.patch


# Make some default choices on checkfile locations for xymond and
# xymond_alert; assume in xymond that if a checkfile is found, 
# we're restarting off that (like xymond_alert does).
Patch64: xymon.defaultchk.patch

# Control logging and PIDFILE generation from xymonlaunch
# instead of the individual xymon programs
Patch65: xymon.launchpidfile.patch
Patch66: xymon.launchlogging.patch

# Remove default PID writing from xymond, xymonproxy, msgcache, and xymond_history
# unless actually specified
Patch67: xymon.nopid.patch
Patch367: xymon_trunk.nopid.patch


# Add clientconfig command
Patch68: xymon.clientconfig.patch
Patch368: xymon_trunk.clientconfig.patch

# Add a 28-day HWPREDICT (and MIN/MAX for the 12/48 day records) to the default rrddefinitions.cfg file
# Also, remove the compiled default if rrddefinitions.cfg is not available (throw an error instead)
Patch69: xymon.rrddefs-hwpredict.patch

# Serve a cached copy of hosts.cfg to requestors until we reload it ourselves
Patch70: xymon.hostconfigcache.patch
Patch370: xymon_trunk.hostconfigcache.patch

# Standardize the header line of xymonnet, xymongen, and xymond a little
Patch71: xymon.reportline.patch
#Patch371: xymon_trunk.reportline.patch

# Verbage changes for xymond status
Patch74: xymon.last10m.patch

## add submitted summary results to nongreen.html
Patch75: xymon.nongreensummaries.patch


# fork the vmstat collector on clients by piping to a shell instead
# of putting it all on a single command line
Patch76: xymon.pipevmstatfork.patch


# Search /usr for libs too
Patch77: xymon.usrlibs.patch


# Better Logging patch; make log rotations more reliable by propagating HUPs
Patch780: xymon.launchsendhup.patch
Patch78: xymon.betterlogging.patch
# Break out the trunk/release patches, since trunk code sets up pidfiles and logfiles differently
Patch79: xymon.evenbetterlogging.patch
Patch379: xymon_trunk.evenbetterlogging.patch

# Don't let a hung xymond_channel or other semaphore user keep us from starting xymond up
#Patch80: xymon.clientcountwarn.patch
Patch380: xymon_branch.clientcountwarn.patch

# Optimize stats and purple calculation in xymond loop, fix off-by-1 err
# Extend subclient expiry time default status TTL time + 2xPURPLE cycles
Patch81: xymon.calc-statspurple-opt.patch

# Don't auto-revert to file load if xymond failed -- xymonnet and xymongen should
# both fail and try again at the next launch -- behavior too unpredicatable at launch
# time otherwise, depending on timeout settings...
Patch82: xymon.nofilerevert.patch


# Patch the workers to pay attention to HUPs and reload their log files
Patch84: xymon.launchlog_workers.patch
#Patch384: xymon_trunk.launchlog_workers.patch

# Rotate logs via killall to xymonlaunch
Patch85: xymon.huplogrota.patch

# Really verbose debugging when loading hostinfo (should be removed at some point)
Patch91: xymon.loadhosts-hostinfodebug.patch

# Keep logfetch status file persistent, even if XYMONTMP points to a tmpfs
Patch95: xymon.logfetchlog.patch


# Some minor cleanups for dietlibc to stop complaining
Patch98: xymon.dietlibcwarnings.patch

# Launch the channel worker process (or try to) before we actually connect to the
# channel the first time
Patch100: xymon.launch1st.patch


# Fork xymond_rrd when doing its final cacheflush, since that can take a while
Patch102: xymon.rrd_doublefork.patch


# Knock out a few more stray dbgprintfs
#Patch108: xymon.dbgprintfs.patch

# Increase the starting and incremental buffer size xymond uses for messages
Patch109: xymon.inbuf.patch

# Fix downtime recovery messages
Patch110: xymon.downtimecolor.patch

# Force c-ares to be re-configured
# to deal with CFLAGS v CPPFLAGS issues in 1.10.0
Patch111: xymon.c-ares-1.10.0.patch

# Add "noprefer" option
Patch113: xymon.noprefer.patch

# Change content-type of HTTP response to text/plain
# and spit something back when given no request (to prevent HTTP 500 errors)
Patch114: xymon.cgimsg-contenttype.patch


# Don't turn xymonnet yellow in the event of a DNS failure
# Still logged out, still turns that dot red, but doesn't indicate a xymonnet failure)
Patch115: xymon.noyellowdnsfail.patch

# Increase max number of xymonproxy server destinations to 5
Patch118: xymon.proxylimit.patch

# xymond_rrd should load its hosts before daemonizing
Patch120: xymon.rrdloadhosts.patch

# slightly tune xymonproxy
Patch121: xymon.proxytune.patch


# Add debug lines to handle_linux_client
Patch122: xymon.client_linux.debug.patch

# Fix depends= parsing in xymonnet (v4)
Patch123: xymon.netdeptests.patch


# Split resetfails and add DELAY option to tasks.cfg
Patch125: xymon.launchdelay.patch


# Add vmstat1-5 graphs
Patch126: xymon.vmstatgraphs.patch


# Experimental combodata message
Patch127: xymon.combodata.patch
Patch427: xymon_trunk.combodata.patch


# xymon client honors $XYMON_TIMEOUT if it's available and --timeout not specified
Patch129: xymon.clienttimeout.patch
Patch130: xymon.retries.patch

# Combine more status messages from xymond_client and
# only flush when needed (use --flushtimeout=)
#Patch124: xymon.client_moarcombo.patch
# 
# patch sendmsg functions to use xymontimeout if available
#Patch130: xymon.sendmsgtimeout.patch

# patch sendmsg with new combodata_add functions
# patch xymond_client to use them
# includes patch124 (moarcombo) and patch130 (timeout) above
#Patch131: xymon.combodata-sendmsgclient-sendmsgtimeout-moarcombo.patch
Patch331: xymon_branch.combodata-sendmsgclient-sendmsgtimeout-moarcombo.patch


#Patch132: xymon.memorydbg.patch
Patch132: xymon.findcookiedebug.patch


# remove an environment variable lookup
# that can segfault when multthreading
Patch133: xymon.noenv.patch


# Reduce semaphore alarms for both xymond_channel and xymond to 1s
Patch134: xymon.shortalarm.patch

# Don't create spurious testname records for fake client status messages
Patch135: xymon.clientcolor.patch


# Let xymond_filestore understand client channel messages
# Needs work...
Patch136: xymon.filestoreclient.patch

# Use bfq in more spots

# add --bfq/--no-bfq options
Patch137: xymon_branch.xymonnet.usebfq.patch
Patch138: xymond_rrd.moarextcombo.patch
Patch141: xymon.combo_addchar.patch

# Fix BFQ vs TCP starvation
Patch142: xymon.tcpcheckinterval.patch
Patch143: xymon.ipcdebug.patch


# parse new client "status" message syntax
Patch144: xymon.clientparse.patch
Patch344: xymon_trunk.clientparse.patch

# Add STATUSMODE variable to xymonclient to send
# via status (needs patch144 above)
Patch145: xymon.statusmode.patch

# On "current status" pages modifiers are H3's above line1, but on
# historical status logs they're between line1 and the start of the regular text
# -- make the current look like the lag
Patch146: xymon.consistentmodifyspot.patch

# Increase bf_bufsz to unsigned int (not int)
# Increase bf_bufsz to size_t? (not int)
Patch147: xymon.bf_bufsz.patch

# KB not B!
#Patch148: xymon.max_backfeedsz.patch
Patch148: xymon.bfqdebug.patch
Patch149: xymon.bfqmsgzero.patch

# More sendmessage timeout work
Patch139: xymon.timeout.patch
Patch339: xymon_trunk.timeout.patch

# Set "now" during xymond_rrd's init to keep us from immediately reloading our config
Patch140: xymon.rrd_now.patch

# Somre more debugging around update stats
Patch150: xymon.channeldebug.patch


# Split bogus/unknown commands from timeouts
Patch151: xymon.timeoutstats.patch
Patch351: xymon_trunk.timeoutstats.patch

Patch152: xymon.tokrinit.patch

# Fix connres being used instead of res
Patch153: xymon.connres.patch

# Remove some close calls in get_clientconfig
Patch154: xymon.clientlocalfaster.patch

# Extend modify syntax to allow variable number of subsequent status overrides
Patch155: xymon.modify-valid.patch

# Use longs for cookies since we're potentially in 64bit land
Patch156: xymon.64bitcookies.patch

# Use unique "modify" tags for each DS line handled by xymond_rrd
Patch157: xymon.rrdds-cfid.patch

# Check for errors getting the current state in xymond_alert and bail out
# (will get relaunched) if xymond doesn't respond...
Patch158: xymon.alert-bailerror.patch

# Consider a stale alert a form of recovery instead of silently dropping them
Patch159: xymon.stalerecovery.patch

# Label log messages from xymond_channel/xymonlaunch
Patch160: xymon.errlabel.patch

# Add XYMONEXNETWORKS= option to xymonserver.cfg and xymonnet
Patch161: xymon.exnetworks.patch

# Add --bfq option to xymonproxy
Patch163: xymon.proxyusebfq.patch


Patch164: xymon.useradmgcc.patch

# BACKPORTED TO CURRENT RELEASE ONLY

# Change title in msgs test from System logs to more PC Log files
Patch105: xymon.msgslogs.patch

# Add missing modify/hostinfo in xymond_stats (already in trunk)
Patch352: xymon.missinglabels.patch



# DIFFERING VERSIONS ONLY
# allow custom http headers to be specified for http tests for a given host
Patch326: xymon_trunk.httpheaders.patch
Patch26: xymon.httpheaders.patch


# Add option to disable saving or using cookies during web tests (non-trunk)
# (Trunk uses xymonnet2)
#Patch316: xymon.cookiesoptional.patch
Patch336: xymon_branch.cookiesoptional.patch

# When saving RRD files for web tests, use the specified column name if one is given
# NOTE: You will need to rename your rrd files at the time of upgrade!
# (Trunk uses xymonnet2)
Patch317: xymon.httpcolnamerrd.patch 

# Check /etc/services for port of 'bb' as well as 'bbd'
# (Trunk already looks it up as 'bb' only)
Patch318: xymon.services-bb.patch

# Add -r to xargs in makefile
Patch319: xymon.safexargs.patch

Patch320: xymon.rrd7316.patch


# TRUNK ONLY
# no need to build the included fping; there's no binary dependency
# (this is RPM, just pull in the distro one via depends)
Patch401: xymon_trunk.nofping.patch

# add zliblibs
Patch402: xymon_trunk.zlibfix.patch

# wrap ssl in HAVE_OPENSSL
Patch403: xymon_trunk.nossl.patch

# let trunk build with <= 3.3.6 sqlite, eg RHEL 5
# TODO: old-style sqlite error handling needs to be added here
#	otherwise we'll need to enforce use of a current version
#	which realistically means building our own like with c-ares
Patch405: xymon_trunk.old_sqlite.patch


# configure.client more like configure.server
Patch406: xymon_trunk.configureclient.patch

# lib/stdopt.c calls malloc now; needs header
Patch408: xymon_trunk.stdopt_malloc.patch

# Forward port of initializing variables in timefunc
Patch409: xymon_trunk.timefunc.patch

# Fix msglen warning with dietlibc
Patch410: xymon_trunk.msglenfix.patch

# Debug combo size
# works: Patch555: xymon.130918.dbg.patch
Patch555: xymon.130918.patch
Patch556: xymon.size.patch
Patch557: xymon.consstrdup.patch


##########################################################################
##########################################################################

%description
Xymon monitors your hosts, your network services, and anything else you
configure it to do via extensions. Xymon will periodically generate
requests to network services - HTTP, FTP, SMTP and so on - and record if
the service is responding as expected. Through the use of agents
installed on the servers (the xymon-client package), you can also
monitor local disk utilization, log files and processes.

Xymon is the successor to the BBGEN toolkit, which has been available as
an add-on to Big Brother since late 2002. It was also previously known
as Hobbit. If you have used BBGEN before, Xymon will seem quite
familiar.

You should install this package if you want this machine to monitor 
services running on other machines.


###########################################################################
%package client
Summary:	The reporting client service for the Xymon monitoring system
Group:		Applications/System
Conflicts:	xymon
Provides:	xymon-client-core%{?_isa} = %{version}-%{release}, xymon-client-passive%{?_isa} = %{version}-%{release}
%if %{with facl}
Requires(post):	   acl
Requires(postun):  acl
%endif
%if %{with selinux}
Requires:	selinux-policy >= %{selinux_policyver}
Requires(post):		/usr/sbin/semodule
Requires(postun):	/usr/sbin/semodule
%endif
%if %{with altshell}
Requires:	%{shell}
%endif

%description client
This package contains a client/agent for the Xymon monitor. Clients
report data about the local system to the monitor, allowing it to check
on the status of the system load, file system utilization, processes that
must be running, and so forth.

This package does not need to be installed on a system that is 
already running as a Xymon server (indeed, it conflicts with it).
The Xymon server already contains the files necessary to run its
built-in monitor.


###########################################################################
%if %{with dietlibc}
%package client-static
Summary:	Static client binaries for the Xymon monitoring system
Group:		Applications/System
Requires:	xymon-client-core%{?_isa} = %{version}-%{release}
%if %{with selinux}
Requires:	selinux-policy >= %{selinux_policyver}
Requires(post):		/usr/sbin/semodule
Requires(postun):	/usr/sbin/semodule
%endif
%if %{with altshell}
Requires:	%{shell}
%endif

%description client-static
This package contains statically-compiled client binaries for the Xymon
monitor. If you already have the client on the system, these binaries may
be used by appending ".static" to xymon, xymoncfg, xymoncmd, xymondigest, or 
xymonlaunch.

If you need this, you probably already know what you're doing. Most people
won't need this package.


###########################################################################
%endif

%if %{with extraclients}
%package client-passive
Summary:	Run-time utilities and a client for the Xymon monitoring system
Group:		Applications/System
Conflicts:	xymon xymon-client
Provides:	xymon-client%{?_isa} = %{version}-%{release}, xymon-client-core%{?_isa} = %{version}-%{release}
%if %{with selinux}
Requires:	selinux-policy >= %{selinux_policyver}
Requires(post):		/usr/sbin/semodule
Requires(postun):	/usr/sbin/semodule
%endif
%if %{with altshell}
Requires:	%{shell}
%endif

%description client-passive
This package contains run-time utilities and a manual client for
communicating with the Xymon monitor. It does not set up a user account
and does not contain init scripts for the client agent.

You should install this package if you want to retrieve data 
about a machine on a manual basis or automated outside the bailiwick 
of the xymonlaunch process.

Note that this software may leave temp files around that are owned
by whichever user last ran the client script. You should try to run
the client consistently by the same method.


%package client-core
Summary:	Utilities for communicating with the Xymon monitoring system
Group:		Applications/System

%description client-core
This package contains run-time utilities for communicating with the Xymon
monitor: the xymon, xymoncfg, and xymoncmd commands and associated 
configuration files.

It does not contain the local client daemon which regularly reports 
system status back. You should install xymon-client for that instead.

Install this package if you have scripts which may need to report back a
result, but you cannot or don't want to install the local xymon-client
daemon or scripts.  If you later decide to install the full client, you
can upgrade to either the active or passive client directly over this
one.


%package client-orca
Summary:	Orca collector client for the Xymon monitoring system
Group:		Applications/System

%description client-orca
orcaxymon is an add-on tool for the Xymon client. It is used to grab data 
collected by the ORCA data collection tool (orcallator.se), and send it to 
the Xymon server in NCV format. 


%endif
##########################################################################


# Common directories used on both servers and clients
%define	logDirectory		%{_localstatedir}/log/%{name}
%define runDirectory		%{_localstatedir}/run/%{name}
%define localClientDirectory	%{_prefix}/local/share/%{clientName}

# long-term data for the server, generated html, and templates
%define libDirectory		%{_localstatedir}/lib/%{name}
%define wwwDirectory		%{_localstatedir}/www/%{name}
%define wwwCacheDirectory	%{_localstatedir}/cache/%{serverName}
%define wwwStaticDirectory	%{xymonServerRoot}/static
%define webDirectory		%{_sysconfdir}/%{serverName}/web

# temp directories. if clientshmtmp is specified, the client
# tries to use /dev/shm instead
%define tmpDirectorySrv		%{_localstatedir}/lib/%{name}/tmp
%define tmpDirectoryCli		/dev/shm


##########################################################################
##########################################################################

%prep
%if %{without trunk}
%if %{without branch}
%setup -q
%else
%setup -q -n %{name}-%{branchVer}
%endif
%else
%setup -q -n trunk
%endif



# "/static"
%patch1 -b .installstaticwww
%patch2 -b .helpdir
%patch45 -b .mkdir
%patch46 -b .varlibwww


# Package management / RPM complaints / FHS
%patch4 -b .sections
%patch5 -b .breakout
%patch8 -b .noclientupdate
%patch13 -b .usrlocallocaldir
# confreport_back.patch
%patch49
%patch52 -b .alwaysmultiservers
%patch53 -b .usesysconfig
%patch54 -b .serverclient


# Build chain
%patch6 -b .initdvars
%patch56 -b .logprintf


# command pipeline/conveniences
%patch30 -b .quietcmd
%patch36 -b .clienthomecheck
%patch41 -b .xymonmsg
%patch50 -b .homelesscmd
%patch59 -b .shellinclude
%patch18 -b .nullfollowsincl


# WWW ease of use
%patch47 -b .dirredir
%patch51 -b .wwwcachedir
%patch44 -b .trendsloop


# runtime reliability
%patch15 -b .nosleep
%patch48 -b .sigbetter
%patch61 -b .resetfails
%patch102 -b .doublefork
%patch109 -b .inbuf
%patch158 -b .bailerror
%patch159 -b .stalerecovery
%patch160 -b .errlabel


## depending on if defaulttaskscfg has been applied, white space has changed
patch -s -p0 --fuzz=0 --ignore-whitespace < %{PATCH65}
## %patch65 -b .launchpidfile

%patch66 -b .launchlogging


# UI
%patch74 -b .last10m
%patch75 -b .nongreensummaries
%patch76 -b .pipevmstatfork

# Build
%patch77 -b .usrlibs

# Logging
%patch17 -b .dbgmacro
%patch780 -b .launchsendhup
%patch78 -b .betterlogging
%patch85 -b .huplogrota
%patch81 -b .calc-statspurple-opt


# Only when debugging
#%patch91 -b .safestrcasecmp
#%patch91 -b .hostinfodebug
%patch132 -b .findcookiedebug



# Performance
%patch100 -b .launch1st
%patch95 -b .logfetchlog

# Max server xymonproxy increase to 5
%patch118 -b .proxylimit

# Build
%patch98 -b .dietlibcwarnings

%patch110 -b .downtimecolor
%patch84 -b .launchlog


# update c-ares version
%patch111 -b .c-ares-1.10.0-shim
install -m 644 %{SOURCE11} xymonnet/
perl -pi -e 's/ARESVER = [\d.]+/ARESVER = %{caresVer}/' build/Makefile.rules


# update md5 version
#mkdir md5
#tar --directory=md5/ -xzvf %{SOURCE13}
#mv lib/md5.c lib/md5.c.back
#mv lib/md5.h lib/md5.h.back
#cp -fp md5/md5.c md5/md5.h lib/


# New feat
%patch113 -b .noprefer
%patch114 -b .cgimsg
%patch60 -b .epoch_histlogs


%patch120 -b .rrdloadhosts
%patch121 -b .proxytune
%patch125 -b .launchdelay
%patch126 -b .vmstatgraphs


# occasional segfault multithreading in xymonproxy.c with getenv
%patch133 -b .noenv


# xymon.c $ENV{XYMON_TIMEOUT} support
%patch129 -b .clienttimeout

# short semaphore alarms
%patch134 -b .shortalarm
%patch135 -b .clientcolor

#%patch136 -b .filestoreclient

%patch140 -b .now
%patch150 -b .channeldebug
%patch154 -b .clientlocalfaster
%patch155 -b .modify-valid
%patch156 -b .lgcookie
%patch157 -b .rrdds

%patch164 -b .gcc48


####################################################
%if %{without trunk}
##############################

%patch115 -b .noyellowdnsfail

## 4.3.xx
%patch122 -b .clientlinuxdbg
%patch123 -b .netdeptests
%patch68 -b .clientconfig

# xymond support for combodata
%patch127 -b .combodata

%patch139 -b .timeout
%patch130 -b .retries
%patch151 -b .timeoutstats
%patch352 -b .missinglabels


%patch148 -b .bfqdebug

%patch152 -b .tokrinit
#%patch340
#%patch341
%patch327 -b .datahttp
%patch336 -b .optcook

# trunk uses xymonnet2
%patch137 -b .bfq

# rrd
%patch138 -b .moarextcombo
%patch69 -b .rrddefs-hwpredict

%patch142 -b .tcpcheckinterval
%patch149 -b .bfqmsgzero


%patch380 -b .clientcountwarn
%patch144 -b .clientparse
%patch145 -b .statusmode
%patch146 -b .consistentmodifyspot
%patch147 -b .bf_bufsz

%patch331 -b .combodata-sendmsgclient-sendmsgtimeout-moarcombo

# needed for dietlibc -- msglen_t -> size_t
%patch410 -b .msglenfix

%patch555 -b .130918.dbg
%patch556 -b .size
#%patch557 -b .consstrdup

%patch3 -b .rundir
%patch26 -b .httpheaders

%patch67

%patch70 -b .hostconfigcache



# UI backport
%patch71 -b .reportline

%patch317 -b .httpcolnamerrd
%patch318 -b .bb
%patch319 -b .safexargs
%patch320 -b .rrd

# feature diffs
%patch82 -b .nofilerevert
%patch55 -b .morexymondlogs
%patch79 -b .betterlogging
%patch161 -b .exnet


# UI
%patch105 -b .msgslogs


##############################
%else
########## with trunk only
##############################

# update sqlite version
install -m 644 %{SOURCE12} ./

%patch303 -b .rundir
%patch326 -b .httpheaders
%patch368 -b .clientconfig

# xymond support for combodata
%patch427 -b .combodata

%patch344 -b .clientparse
%patch145 -b .statusmode

%patch339 -b .timeout

%patch351 -b .timeoutstats

%patch355 -b .morexymondlogs
%patch367
%patch370 -b .hostconfigcache
%patch379 -b .betterlogging

%patch401 -b .nofping
%patch402 -b .zlibfix
%patch403 -b .nossl
#%patch405 -b .old_sqlite
%patch406 -b .configureclient
%patch408 -b .malloc
%patch409 -b .null

# needed for dietlibc -- msglen_t -> size_t
%patch410 -b .msglenfix

%endif
#######################################################################

# Packaging, add SENDHUP
%patch603 -b .rundir-tasks

# BFQ xymonproxy
%patch141 -b .combo_addchar
%patch163 -b .proxyusebfq


%if %{without trunk}
  PROTOFILE="xymonnet/protocols.cfg"
%else
  PROTOFILE="xymonnet/protocols2.cfg"
%endif
  echo "
# include additional sections
directory @XYMONHOME@/etc/protocols.d" >> $PROTOFILE


# Fix snmp rcsid warning
%{__perl} -pi -e 's/^static char rcsid/static char snmpcollect_rcsid/' ./xymonnet/xymon-snmpcollect.c


# fix perms on patch4
  chmod 644 client/README-sections*

# Ensure that any utf8 data perl scans will read OK on RH8
  export LANG=C


# Updated init scripts
  rm -f rpm/xymon-init.d rpm/xymon-client.init
  install -m 644 %{SOURCE1} rpm/xymon-init.d.DIST
  install -m 644 %{SOURCE2} rpm/xymon-client.init.DIST
  %{__perl} -p -e 's#PROGRAMS = xymon.sh#PROGRAMS = ../rpm/xymon-init.d ../rpm/xymon-client.init xymon.sh#' -i xymond/Makefile
  %{__perl} -p -e 's#PROGRAMS=xymonlaunch#PROGRAMS=../rpm/xymon-client.init xymonlaunch#' -i client/Makefile

%if %{with selinux}
  mkdir SELinux
  install -m 644 %{SOURCE41} SELinux/%{serverName}.te
  install -m 644 %{SOURCE42} SELinux/%{clientName}.te
  %{__perl} -p -e 's/VERSION/%{version}.%{release}/' -i SELinux/*.te
%endif


# Search and replace our shells?
%if %{with altshell}
# Init script launching
  %{__perl} -p -e 's#-s /bin/sh#-s %{shell}#' -i rpm/xymon-init.d* rpm/xymon-client.init*

# Update all generic forking
  %{__perl} -p -e 's#SHELL="/bin/sh"#SHELL="%{shell}"#' -i client/xymonclient.cfg.DIST xymond/etcfiles/xymonserver.cfg.DIST

# Client-side (on Linux, for the client RPM) forking
  %{__perl} -p -e 's#nohup sh #nohup %{shell} #' -i ./client/xymonclient-linux.sh

# Script shebangs generally (web shims, etc)
  find -type f | grep -e .sh$ -e .sh.DIST$ | grep -v /build/ | \
	xargs -r %{__perl} -p -e 's|^#!/bin/sh|#!%{shell}|' -i
%endif



# Convert remaining configure-time tweaked paths to their fixed equivalents.
# eg, /usr/share/xymon/server/etc/tasks.cfg is now:
#     /etc/xymon/tasks.cfg

find -type f > tmp.flist
find xymond/ xymongen/ xymonnet/ xymonproxy/ rpm/xymon-init.d.DIST -type f > tmp.slist

xargs -r %{__perl} -p \
	-e 's#\@XYMONTOPDIR\@/server/bin/xymond\b#%{_sbindir}/xymond#g;'	\
	-e 's#\@XYMONTOPDIR\@/server/bin/xymonlaunch\b#%{_sbindir}/xymonlaunch#g;'	\
	-e 's#\@XYMONTOPDIR\@/server/bin#%{_libexecdir}/%{serverName}#g;'	\
	-e 's#\@XYMONTOPDIR\@/server/etc#%{_sysconfdir}/%{serverName}#g;'	\
	-e 's#\@XYMONTOPDIR\@/server/ext#%{_sysconfdir}/%{serverName}/ext#g;' \
	-e 's#\@XYMONTOPDIR\@/client/bin/xymonlaunch\b#%{_sbindir}/xymonlaunch#g;'	\
	-e 's#\@XYMONTOPDIR\@/client/bin#%{_libexecdir}/%{clientName}#g;'	\
	-e 's#\@XYMONTOPDIR\@/client/etc#%{_sysconfdir}/%{clientName}#g;'	\
	-e 's#\@XYMONTOPDIR\@/client/ext#%{xymonClientRoot}/ext#g;'	\
	-e 's#\@XYMONTOPDIR\@/client"#%{xymonClientRoot}"#g;'		\
		-i < tmp.flist
xargs -r %{__perl} -p \
	-e 's#\@XYMONHOME\@/bin#%{_libexecdir}/%{serverName}#g;' \
	-e 's#\@XYMONHOME\@/etc#%{_sysconfdir}/%{serverName}#g;' \
	-e 's#\@XYMONHOME\@/ext#%{_sysconfdir}/%{serverName}/ext#g;' \
		-i < tmp.slist

rm -f tmp.flist tmp.slist


##########################################################################
##########################################################################

%build
# Remove hard-coded compiler options so we can use our own
%{__perl} -p -e 's/^CC/#CC/g;' -e 's/^CFLAGS/#CFLAGS/g;' -i build/Makefile.Linux

%if %{with dietlibc}
  # Include strings.h in code that has a str(n)casecmp function, which may not always be in "string.h"
  # This kind of stuff gets caught with automake, but we're not using that here
    find -type f | grep \.c$ | xargs -r grep -l -e strcasecmp -e strncasecmp -e histlogtime | xargs -r \
	%{__perl} -p -e 's|#include <string.h>|#include <string.h>\n#include <strings.h>|' -i.dietback

  # Build static dietlibc client before the regular server
    export ENABLESSL=n SSLOK=NO \
	XYMONUSER=xymon \
	XYMONTOPDIR=%{xymonRoot} \
	XYMONHOSTIP=127.0.0.1 \
	CONFTYPE=server \
	CC="diet -Os gcc -lcompat" \
	CFLAGS="%{optflags} -DREALLY_SMALL -finline-functions -lcompat"
	LDFLAGS="${LDFLAGS} %{__global_ldflags} -lcompat"

    ./configure.client
    make PKGBUILD=1 client
    cp -fpR client client-diet

  # Move our tweaked files back so as to not affect the regular build
    find -type f -iname \*.dietback | %{__perl} -p -e 's/\.dietback//' | xargs -r -i mv {}.dietback {}
    make distclean
%endif


export	CC="gcc" \
	CFLAGS="%{optflags} -pthread"


# c-ares as of 1.10.0 cares about the CFLAGS/CPPFLAGS distinction
cat >xymonnet/c-ares-shim.sh <<HERE
#!/bin/sh

for i in \$CFLAGS; do
   if [ \`echo \$i | grep -c -e '-I' -e '-D'\` -eq 0 ]; then
	CFF="\$CFF \$i"
   else
	CPF="\$CPF \$i"
   fi
done
CFLAGS="\$CFF" CPPFLAGS="\$CPF" \$*
HERE
chmod 755 xymonnet/c-ares-shim.sh



export	USEXYMONPING=n \
	USERFPING=%{_sbindir}/fping \
	ENABLESSL=y SSLOK=YES \
	ENABLELDAP=y \
	ENABLELDAPSSL=y \
	CONFTYPE=server \
	XYMONUSER=xymon \
	XYMONTOPDIR=%{xymonRoot} \
	XYMONVAR=%{libDirectory} \
	XYMONHOSTURL=/xymon \
	CGIDIR=%{xymonServerRoot}/cgi-bin \
	XYMONCGIURL=/xymon-cgi \
	SECURECGIDIR=%{xymonServerRoot}/cgi-secure \
	SECUREXYMONCGIURL=/xymon-seccgi \
	HTTPDGID=apache \
	XYMONLOGDIR=%{logDirectory} \
	XYMONRUNDIR=%{runDirectory}	\
	XYMONHOSTNAME=localhost \
	XYMONHOSTIP=127.0.0.1 \
	MANROOT=%{_mandir} \
	INSTALLBINDIR=%{_libexecdir}/%{serverName} \
	INSTALLETCDIR=%{_sysconfdir}/%{serverName} \
	INSTALLEXTDIR=%{_sysconfdir}/%{serverName}/ext \
	INSTALLWEBDIR=%{webDirectory} \
	INSTALLTMPDIR=%{tmpDirectorySrv} \
	INSTALLWWWDIR=%{wwwDirectory} \
	INSTALLSTATICWWWDIR=%{wwwStaticDirectory}
%if %{with snmp}
	export SNMP=1
%endif



# this is not gnu autoconf -- can't use macro
./configure

# Make
# %{__perl} -p -e 's/^# XYMONLIBRARY=libxymon.so/XYMONLIBRARY=libxymon.so/' -i build/Makefile.Linux
make PKGBUILD=1


%if %{with selinux}
pushd SELinux
for selinuxvariant in %{selinux_variants} ; do
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
    mv %{serverName}.pp %{serverName}.pp.${selinuxvariant}
    mv %{clientName}.pp %{clientName}.pp.${selinuxvariant}
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done
popd
%endif


##########################################################################
##########################################################################

%install
rm -fR %{buildroot}
install -d %{buildroot}%{wwwCacheDirectory}
install -d %{buildroot}%{runDirectory}
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_sbindir}
make PKGBUILD=1 INSTALLROOT=%{buildroot} install

install -m 644 %{SOURCE5} README.terabithia
install -m 644 %{SOURCE6} CHANGES.terabithia


%if %{with dietlibc}
   # Copy the smaller, static client binaries back into the client section
   for bin in xymon xymoncfg xymoncmd xymondigest xymongrep xymonlaunch logfetch msgcache; do
	install -m 755 client-diet/$bin %{buildroot}%{xymonRoot}/client/bin/${bin}.static
   done
%endif


# Fix a utf8 warning from rpmlint
  iconv --from=ISO-8859-1 --to=UTF-8 CREDITS > CREDITS.utf8 && \
	touch -r CREDITS CREDITS.utf8 && mv CREDITS.utf8 CREDITS

# Move client home directory to /usr/share/xymon-client
  mv %{buildroot}%{xymonRoot}/client %{buildroot}%{xymonClientRoot}
  ln -s %{xymonClientRoot} %{buildroot}%{xymonRoot}/client

# Handled below
  rm -f %{buildroot}%{xymonClientRoot}/{local,sections}/README


# Install init scripts or systemd unit file.
# NB: the systemd "xymon" service file is unified -- it runs xymonlaunch,
#   which will look in the package-designated location for a xymonserver.cfg
#   and then a xymonclient.cfg file. There is no xymon/xymon-client service difference.
#
%if %{with systemd}
  install -d %{buildroot}%{_unitdir}
  install -d %{buildroot}%{_presetdir}
  install -m 644 %{SOURCE8} %{buildroot}%{_unitdir}/xymonlaunch.service
  install -m 644 %{SOURCE10} %{buildroot}%{_presetdir}/98-xymonlaunch.preset

%else
  install -d %{buildroot}%{_initrddir}
  mv %{buildroot}%{_libexecdir}/%{serverName}/xymon-init.d %{buildroot}%{_initrddir}/%{serverName}
  mv %{buildroot}%{xymonClientRoot}/bin/xymon-client.init %{buildroot}%{_initrddir}/%{clientName}
%endif

  rm -f %{buildroot}%{_libexecdir}/%{serverName}/xymon-client.init
  rm -f %{buildroot}%{_libexecdir}/%{serverName}/xymon.sh
  rm -f %{buildroot}%{xymonClientRoot}/runclient.sh
  rm -f %{buildroot}%{xymonRoot}/server/xymon.sh 

# Install the apache config and touch htpasswd files
  touch %{buildroot}%{_sysconfdir}/%{serverName}/xymonpasswd
  touch %{buildroot}%{_sysconfdir}/%{serverName}/xymongroups

  install -d %{buildroot}%{_sysconfdir}/httpd/conf.d
  mv -f %{buildroot}%{_sysconfdir}/%{name}/xymon-apache.conf \
	%{buildroot}%{_sysconfdir}/httpd/conf.d/%{serverName}.conf
  install -m 644 %{SOURCE9} .

  ### add /hobbit -> /xymon compatibility line for previous package versions
  echo "RewriteRule ^/hobbit(.*) /xymon\$1 [R=permanent,L]" >> \
	%{buildroot}%{_sysconfdir}/httpd/conf.d/%{serverName}.conf

# if building for apache 2.4+, change the default config syntax appropriately
%if %{with httpd24}
  %{__perl} -p -e 's/Order allow,deny\s+#?\s*Allow from all/Require all granted/gs' -i %{buildroot}%{_sysconfdir}/httpd/conf.d/*.conf
%endif


# Only if needed
  %if %{with snmp}
    touch %{buildroot}%{_sysconfdir}/%{serverName}/snmphosts.cfg
  %endif

# Certs = config files
  install -d %{buildroot}%{_sysconfdir}/%{serverName}/certs
  ln -s %{_sysconfdir}/%{serverName}/certs %{buildroot}%{xymonRoot}/server/certs


# Dynamically create these directories if/when needed
  rmdir %{buildroot}%{wwwDirectory}/{html,notes,rep,snap,wml} 
  rmdir %{buildroot}%{libDirectory}/logs		# this is for [storestatus], not /var/log/xymon

# we've moved the positions of some of these directories
  %{__perl} -p	-e 's#\$XYMONWWWDIR/rep#%{wwwCacheDirectory}/rep#g;'	\
	-e 's#\$XYMONWWWDIR/snap#%{wwwCacheDirectory}/snap#g;'	\
	-e 's#\$XYMONHOME/static#%{wwwStaticDirectory}#g;'	\
	-e 's#\$XYMONHOME/www#%{wwwDirectory}#g;'			\
		-i %{buildroot}%{_sysconfdir}/%{serverName}/xymonserver.cfg


# logrotate scripts for servers and clients
  install -d %{buildroot}%{_sysconfdir}/logrotate.d
  install -m 644 rpm/xymon.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/xymon
  %{__perl} -p	-e 's#/var/log/xymon/\*.log#%{logDirectory}/*.log#;' \
		-e 's#/etc/init.d/xymon rotate#killall -HUP xymonlaunch >/dev/null 2>/dev/null#;' -i %{buildroot}%{_sysconfdir}/logrotate.d/xymon
  cp -fp %{buildroot}%{_sysconfdir}/logrotate.d/xymon %{buildroot}%{_sysconfdir}/logrotate.d/xymon-client

# sysconfig files for servers and clients
  install -d %{buildroot}%{_sysconfdir}/sysconfig
  install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/xymonlaunch
  install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{clientName}
  %{__perl} -p -e 's#/etc/default/#%{_sysconfdir}/sysconfig/#' -i %{buildroot}%{_initrddir}/*

# fix permissions
  install -m 644 %{SOURCE51} %{buildroot}%{wwwStaticDirectory}/gifs/info.gif
  install -m 644 %{SOURCE52} %{buildroot}%{wwwStaticDirectory}/gifs/client.gif
  install -m 644 %{SOURCE53} %{buildroot}%{wwwStaticDirectory}/gifs/trends.gif
  find %{buildroot}%{wwwStaticDirectory} -type f | xargs -r chmod 644


# disable "clientupdate", which won't work on RPM systems
  rmdir %{buildroot}%{xymonRoot}/server/download/
  rm -f %{buildroot}%{xymonClientRoot}/bin/clientupdate
  rm -f %{buildroot}%{_mandir}/*/clientupdate.*


# remove unneeded HOME variables
  %{__perl} -p -e 's#\$XYMONHOME/bin#%{_libexecdir}/%{clientName}#g;' -e 's#\$XYMONHOME/#%{xymonClientRoot}/#g;' \
	-i %{buildroot}%{xymonClientRoot}/etc/xymonclient.cfg %{buildroot}%{xymonClientRoot}/bin/xymonclient.sh

  %{__perl} -p -e 's#\$XYMONHOME/bin#%{_libexecdir}/%{serverName}#g;' -e 's#\$XYMONHOME/etc#%{_sysconfdir}/%{serverName}#g;'	\
	-i %{buildroot}%{_sysconfdir}/%{serverName}/xymonserver.cfg


# Save a fork and hard-code our version into xymonclient.sh
  %{__perl} -p -e 's/`\$XYMON --version`/Xymon version %{version}-%{release}/' -i %{buildroot}%{xymonClientRoot}/bin/xymonclient.sh


# Since environment is always set, full pathnames aren't needed
  %{__perl} -p	-e 's#CMD \$XYMONCLIENTHOME/bin/#CMD #g;'	-e 's#CMD %{_libexecdir}/%{clientName}/#CMD #g;' \
	-e 's#CMD \$XYMONHOME/ext/#CMD %{_sysconfdir}/%{serverName}/ext/#g;' \
	-e 's#CMD \$XYMONHOME/bin/#CMD #g;' \
	-e 's#\$XYMONHOME/logs#%{logDirectory}#g;' \
	-i %{buildroot}%{_sysconfdir}/%{serverName}/tasks.cfg

  %{__perl} -p	-e 's#CMD \$XYMONCLIENTHOME/bin/#CMD #g;'				\
	-e 's#CMD \$XYMONCLIENTHOME/ext/#CMD %{_sysconfdir}/%{clientName}/ext/#g;' \
	-e 's#\$XYMONCLIENTHOME/etc#%{_sysconfdir}/%{clientName}#g;'	\
	-e 's#CMD %{xymonRoot}/client/bin/#CMD #g;'			\
	-i %{buildroot}%{xymonClientRoot}/etc/clientlaunch.cfg

  %{__perl} -p	-e 's#\$XYMONHOME/bin#%{_libexecdir}/%{serverName}#g;' -i %{buildroot}%{_libexecdir}/%{serverName}/*.sh

   if [ -f %{buildroot}%{_sysconfdir}/%{serverName}/ext/xymonnet-again.sh ] ; then
	%{__perl} -p -e 's#\$XYMONHOME/bin#%{_libexecdir}/%{serverName}#g;' -i %{buildroot}%{_sysconfdir}/%{serverName}/ext/xymonnet-again.sh 
   fi

# Move client-ish client binaries to /usr/bin
  pushd %{buildroot}%{xymonClientRoot}
    for this in xymon xymoncfg xymoncmd xymondigest xymongrep logfetch msgcache; do
       mv -f bin/$this %{buildroot}%{_bindir}/$this
       ln -s %{_bindir}/$this bin/$this
%if %{with dietlibc}
	if [ -f "bin/${this}.static" ] ; then
	    mv -f bin/${this}.static %{buildroot}%{_bindir}/${this}.static
	    ln -s %{_bindir}/${this}.static bin/${this}.static
	fi
%endif
    done

# Move server-ish client binaries to /usr/sbin
    for this in xymonlaunch; do
       mv -f bin/$this %{buildroot}%{_sbindir}/$this
       ln -s %{_sbindir}/$this bin/$this
%if %{with dietlibc}
	if [ -f "bin/${this}.static" ] ; then
	    mv -f bin/${this}.static %{buildroot}%{_sbindir}/${this}.static
	    ln -s %{_sbindir}/${this}.static bin/${this}.static
	fi
%endif
    done

# Put the rest of the home directory in their proper places
    mv -f bin %{buildroot}%{_libexecdir}/%{clientName}
    mv -f etc %{buildroot}%{_sysconfdir}/%{clientName}
    ln -s %{_libexecdir}/%{clientName}	bin
    ln -s %{_sysconfdir}/%{clientName}	etc
    rmdir local logs
    ln -s %{logDirectory} logs
  popd

# Move server-ish server binaries to /usr/sbin
# (xymonlaunch overwrites "server-ish client binaries" above)
  pushd %{buildroot}%{_libexecdir}/%{serverName}
    for this in xymond xymonlaunch; do
       mv -f $this %{buildroot}%{_sbindir}/$this
       ln -s %{_sbindir}/$this $this
    done
  popd

# Make sure XYMONTMP and PATH are always set properly
  %{__perl} -p -e 's#XYMONTMP=".*"#XYMONTMP="%{tmpDirectorySrv}"#g;' -i %{buildroot}%{_sysconfdir}/%{serverName}/xymonserver.cfg
  %{__perl} -p -e 's#XYMONTMP=".*"#XYMONTMP="%{tmpDirectoryCli}"#g;' -i %{buildroot}%{_sysconfdir}/%{clientName}/xymonclient.cfg
  %{__perl} -p -e 's#PATH="#PATH="%{_libexecdir}/%{serverName}:#' -i %{buildroot}%{_sysconfdir}/%{serverName}/xymonserver.cfg
  %{__perl} -p -e 's#PATH="#PATH="%{_libexecdir}/%{clientName}:#' -i %{buildroot}%{_sysconfdir}/%{clientName}/xymonclient.cfg

# Now that XYMOMTMP is hard-coded to where we need it; remove extraneous symlinks which RPM complains about
  rmdir %{buildroot}%{xymonClientRoot}/tmp
  rm -f %{buildroot}%{xymonServerRoot}/tmp


# Big Brother compatibility symlinks
  ln -s xymon %{buildroot}%{_bindir}/bb
  ln -s xymoncmd %{buildroot}%{_bindir}/bbcmd
  ln -s %{_bindir}/xymon %{buildroot}%{_libexecdir}/%{clientName}/bb
  ln -s %{_bindir}/xymoncmd %{buildroot}%{_libexecdir}/%{clientName}/bbcmd
  ln -s xymon.1 %{buildroot}%{_mandir}/man1/bb.1
  ln -s xymoncmd.1 %{buildroot}%{_mandir}/man1/bbcmd.1

%if %{with dietlibc}
  # Duplicate man pages for static versions
   for bin in xymon xymoncfg xymoncmd xymondigest xymongrep logfetch; do
	ln -s ${bin}.1 %{buildroot}%{_mandir}/man1/${bin}.static.1
   done
   for bin in xymonlaunch msgcache; do
	ln -s ${bin}.8 %{buildroot}%{_mandir}/man8/${bin}.static.8
   done
%endif


# Since it's writable by apache, move critical.cfg out of /etc/xymon
  install -d %{buildroot}%{libDirectory}/configs/
  mv %{buildroot}%{_sysconfdir}/%{serverName}/critical.cfg %{buildroot}%{libDirectory}/configs/critical.cfg
  rm -f %{buildroot}%{_sysconfdir}/%{serverName}/critical.cfg.bak

  ln -s %{libDirectory}/configs/critical.cfg %{buildroot}%{_sysconfdir}/%{serverName}/critical.cfg
  ln -s %{xymonClientRoot}/ext %{buildroot}%{_sysconfdir}/%{clientName}/ext


%if %{with extraclients}
  install -m 644 %{SOURCE7} README.core
%else
  ## remove orcaxymon from tree
  rm -f %{buildroot}%{_libexecdir}/%{clientName}/orcaxymon
  rm -f %{buildroot}%{_mandir}/*/orcaxymon.*
%endif


# Create /etc/xymon*/*.d/ configuration directories
# For the server
  for THIS in alerts analysis graphs combo protocols tasks; do
      install -d %{buildroot}%{_sysconfdir}/%{serverName}/${THIS}.d
  done
# For the client
  install -d %{buildroot}%{_sysconfdir}/%{clientName}/client.d
  echo "
# Include add-on modules -- do not confuse with /local/ scripts, which are tests inserted directly into the client report
directory %{_sysconfdir}/%{clientName}/client.d" >> %{buildroot}%{_sysconfdir}/%{clientName}/clientlaunch.cfg


# Add sections to client
  install -m 755 %{SOURCE21} %{buildroot}%{xymonClientRoot}/sections/mounts
  install -m 755 %{SOURCE22} %{buildroot}%{xymonClientRoot}/sections/meminfo
  install -m 755 %{SOURCE23} %{buildroot}%{xymonClientRoot}/sections/vmstats
  install -m 755 %{SOURCE24} %{buildroot}%{xymonClientRoot}/sections/ipcs

# Automatic periodic SLA reports (daily/weekly/monthly)
  install -m 644 %{SOURCE31} %{buildroot}%{_sysconfdir}/%{serverName}/tasks.d/dailyreport
  install -m 644 %{SOURCE32} %{buildroot}%{_sysconfdir}/%{serverName}/tasks.d/weeklyreport
  install -m 644 %{SOURCE33} %{buildroot}%{_sysconfdir}/%{serverName}/tasks.d/monthlyreport

# Add logfetchupdate client.d script
  install -m 755 %{SOURCE61} %{buildroot}%{xymonClientRoot}/ext/logfetchupdate
  install -m 644 %{SOURCE62} %{buildroot}%{_sysconfdir}/%{clientName}/client.d/logfetchupdate.cfg

# deal with alternative shells
  %if %{with altshell}
	%{__perl} -p -e 's#/bin/sh#%{shell}#' -i %{buildroot}%{xymonClientRoot}/sections/*
  %endif


%if %{with selinux}
  # SELinux policy
  for selinuxvariant in %{selinux_variants}; do
    install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
    for policyname in %{serverName} %{clientName}; do
	install -p -m 644 SELinux/${policyname}.pp.${selinuxvariant} %{buildroot}%{_datadir}/selinux/${selinuxvariant}/${policyname}.pp
    done
  done
%endif

# For server tests, increase the frequency of all 5m testing up to 1m; xymonnet-again to 30s
  %{__perl} -p -e 's/INTERVAL 5m/INTERVAL 1m/g;'	-i %{buildroot}%{_sysconfdir}/%{serverName}/tasks.cfg
  %{__perl} -0pe 's/xymonnetagain.log\n\tINTERVAL \d+\w?/xymonnetagain.log\n\tINTERVAL 30s/s' -i %{buildroot}%{_sysconfdir}/%{serverName}/tasks.cfg

# For client reports, increase the frequency from 5m to 100s
  %{__perl} -p -e 's/INTERVAL 5m/INTERVAL 100s/g;' -i %{buildroot}%{_sysconfdir}/%{clientName}/clientlaunch.cfg
  %{__perl} -0pe 's/xymonclient.log\n\tINTERVAL \d+\w?/xymonclient.log\n\tINTERVAL 100s/s' -i %{buildroot}%{_sysconfdir}/%{serverName}/tasks.cfg


##########################################################################
##########################################################################

%clean
rm -fR %{buildroot}


#######################################################################
%pre
# create user if it doesn't exist
getent passwd xymon >/dev/null || \
	useradd -r -d "%{xymonRoot}" -s /sbin/nologin  -c "xymon Monitor" xymon 2>/dev/null || :

%if %{with logreader}
  getent group "%{logReaderGroup}" >/dev/null
  if [ "$?" -ne 0 ] ; then
    echo "xymon logfetch requires group '%{logReaderGroup}' to be present first" >&2
    exit 1
  fi
  # add to any existing user too (eg, upgrades)
  usermod -a -G "%{logReaderGroup}" xymon 2>/dev/null || :
%endif


# check for local client upgrade from < 4.3.0
if [ -r "%{_sysconfdir}/sysconfig/%{clientName}" ] ; then
   if [ "`grep -c ^HOBBITSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -gt 0 -a \
	"`grep -c ^XYMONSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -eq 0 ]
   then
	sed -e 's/^HOBBITSERVERS=\(.*\)$/XYMONSERVERS=\1\nHOBBITSERVERS=\1/' -i %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null
   fi
fi

# xymonping has been removed, must use fping now
  sed -e 's#^FPING=".*xymonping"#FPING="%{_sbindir}/fping"#' -i %{_sysconfdir}/%{serverName}/xymonserver.cfg* 2>/dev/null

# handle upgrades prior to 4.3.7-24 (xymond.chk goes to rundir)
#if [ -e "%{tmpDirectorySrv}/xymond.chk" -a ! -L "%{tmpDirectorySrv}/xymond.chk" ] ; then
#	mkdir -p %{runDirectory}/
#	mv "%{tmpDirectorySrv}/xymond.chk" "%{runDirectory}/xymond.chk"	|| :
#	%{__ln_s} "%{runDirectory}/xymond.chk" "%{tmpDirectorySrv}/xymond.chk" || :
#fi

# handle upgrades prior to 4.3.7-23 (/rep and /snap)
for THIS in rep snap ; do
  if [ -d "%{wwwDirectory}/$THIS" -a ! -L "%{wwwDirectory}/$THIS" ] ; then
	mkdir -p %{wwwCacheDirectory}
	mv %{wwwDirectory}/$THIS %{wwwCacheDirectory}/		2>/dev/null	|| :
	mv %{wwwDirectory}/$THIS/* %{wwwCacheDirectory}/$THIS	2>/dev/null	|| :
	rmdir %{wwwDirectory}/$THIS				2>/dev/null	|| :
  fi
done

# handle upgrades prior to 4.3.7-19 (critical.cfg and /periodic, /notes)
if [ -e "%{_sysconfdir}/%{serverName}/critical.cfg" -a ! -L "%{_sysconfdir}/%{serverName}/critical.cfg" ] ; then
	mkdir -p %{libDirectory}/configs/
	mv %{_sysconfdir}/%{serverName}/critical.cfg* %{libDirectory}/configs/ || :
fi
for THIS in periodic notes ; do
  if [ -d "%{wwwDirectory}/$THIS" -a ! -L "%{wwwDirectory}/$THIS" ] ; then
	mkdir -p %{libDirectory}
	mv %{wwwDirectory}/$THIS %{libDirectory}/		2>/dev/null	|| :
	mv %{wwwDirectory}/$THIS/* %{libDirectory}/$THIS	2>/dev/null	|| :
	rmdir %{wwwDirectory}/$THIS				2>/dev/null	|| :
  fi
done

# handle upgrades prior to 4.3.7-6 (/ext/ and /local/)
if [ -d "%{_sysconfdir}/%{clientName}/ext/" -a ! -L "%{_sysconfdir}/%{clientName}/ext" ] ; then
	mkdir -p %{xymonClientRoot}/ext/
	mv %{_sysconfdir}/%{clientName}/ext/* %{xymonClientRoot}/ext/
	rmdir %{_sysconfdir}/%{clientName}/ext/
fi
# server symlink to the client subdir is new
if [ -d "%{_datadir}/xymon/client/" -a ! -L "%{_datadir}/xymon/client" ] ; then
	mkdir -p %{xymonClientRoot}
	mv %{_datadir}/xymon/client/* %{xymonClientRoot}/
	rmdir %{_datadir}/xymon/client
fi
if [ -d "%{xymonClientRoot}/local/" -a ! -L "%{xymonClientRoot}/local" ] ; then
	mkdir -p %{localClientDirectory}
	mv -f %{xymonClientRoot}/local/* %{localClientDirectory}
	rm -f %{localClientDirectory}/README
	rmdir %{xymonClientRoot}/local
fi


###################################################################
%pre client
# create user if it doesn't exist
getent passwd xymon >/dev/null || \
	useradd -r -d "%{xymonClientRoot}" -s /sbin/nologin  -c "xymon Monitor (client)" xymon 2>/dev/null || :

%if %{with logreader}
  getent group "%{logReaderGroup}" >/dev/null
  if [ "$?" -ne 0 ] ; then
    echo "xymon logfetch requires group '%{logReaderGroup}' to be present first" >&2
    exit 1
  fi
  # add to any existing user too (eg, upgrades)
  usermod -a -G "%{logReaderGroup}" xymon 2>/dev/null || :
%endif


# check for upgrade from < 4.3.0
if [ -r "%{_sysconfdir}/sysconfig/%{clientName}" ] ; then
   if [ "`grep -c ^HOBBITSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -gt 0 -a \
	"`grep -c ^XYMONSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -eq 0 ]
   then
	sed -e 's/^HOBBITSERVERS=\(.*\)$/XYMONSERVERS=\1\nHOBBITSERVERS=\1/' -i %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null
   fi
fi


# handle upgrades prior to 4.3.7-6 (/ext/ and /local/)
if [ -d "%{_sysconfdir}/%{clientName}/ext/" -a ! -L "%{_sysconfdir}/%{clientName}/ext" ] ; then
	mkdir -p %{xymonClientRoot}/ext/
	mv %{_sysconfdir}/%{clientName}/ext/* %{xymonClientRoot}/ext/
	rmdir %{_sysconfdir}/%{clientName}/ext/
fi
if [ -d "%{xymonClientRoot}/local/" -a ! -L "%{xymonClientRoot}/local" ] ; then
	mkdir -p %{localClientDirectory}
	mv -f %{xymonClientRoot}/local/* %{localClientDirectory}
	rm -f %{localClientDirectory}/README
	rmdir %{xymonClientRoot}/local
fi


###################################################################
%post
if [ "$1" -eq 1 ]; then
  # Replace default 'localhost' entries (from install) with our real hostname
  # so we provide useful local info even when not using --local
  HOSTNAME="`uname -n`"
  %{__perl} -p -e "s/ localhost\b/ $HOSTNAME/g;" -e "s/^127.0.0.1/0.0.0.0/g;" -i %{_sysconfdir}/%{serverName}/hosts.cfg
  %{__perl} -p -e "s/^XYMONSERVERS=\"\"\$/XYMONSERVERS=\"127.0.0.1\"/g;" -i %{_sysconfdir}/sysconfig/%{clientName}
fi

# handle upgrades prior to 4.3.10-10 (logfetch status files)
  mv -f %{tmpDirectoryCli}/logfetch.*status %{xymonClientRoot}/logs/ 2>/dev/null || :
# handle upgrades prior to 4.3.10-10 (checkpoint files back in srvTMP)
  for FILE in xymond.chk alert.chk ; do
    test -L "%{tmpDirectorySrv}/$FILE" && rm -f "%{tmpDirectorySrv}/$FILE"
    if [ -e "%{runDirectory}/$FILE" -a ! -L "%{runDirectory}/$FILE" -a ! -e "%{tmpDirectorySrv}/$FILE" ] ; then
	cp -fp "%{runDirectory}/$FILE" "%{tmpDirectorySrv}/$FILE" 2>/dev/null
	rm -f "%{runDirectory}/$FILE"
	%{__ln_s} "%{tmpDirectorySrv}/$FILE" "%{runDirectory}/$FILE"
	chown xymon:xymon "%{runDirectory}/$FILE"
    fi
  done


# Fix duplicate localhost bug
  %{__perl} -p -e "s/\blocalhost\b/$HOSTNAME/g;" -i %{_sysconfdir}/%{serverName}/xymonserver.cfg*
  XYMDAT="`xymoncmd env | grep -e XYMONSERVERIP= -e XYMONSERVERS= -e XYMSERVERS=`"
  SIP=`echo "$XYMDAT" | grep ^XYMONSERVERIP= | %{__perl} -p -e 's/^.*=//'`
  SRV=`echo "$XYMDAT" | grep ^XYMONSERVERS= | %{__perl} -p -e 's/^.*=//'`
  XYM=`echo "$XYMDAT" | grep ^XYMSERVERS= | %{__perl} -p -e 's/^.*=//'`
  if [ x"$SIP" = x"$SRV" -a "$XYM" = "$SIP $SRV" ] ; then
	%{__perl} -p -e 's/^XYMSERVERS=\"\$XYMONSERVERIP \$XYMONSERVERS\"/XYMSERVERS=\"\$XYMONSERVERIP\"	/g;' -i %{_sysconfdir}/%{serverName}/xymonserver.cfg*
  fi

%if %{with selinux}
/usr/sbin/semanage fcontext -a -t initrc_var_run_t		'%{runDirectory}(/.*)?'			|| :
/usr/sbin/semanage fcontext -a -t httpd_cache_t			'%{wwwCacheDirectory}(/.*)?'		|| :
/usr/sbin/semanage fcontext -a -t httpd_sys_script_exec_t	'%{xymonServerRoot}/cgi-bin(/.*)?'	|| :
/usr/sbin/semanage fcontext -a -t httpd_sys_script_exec_t	'%{xymonServerRoot}/cgi-secure(/.*)?'	|| :
/usr/sbin/semanage fcontext -a -t httpd_sys_content_t		'%{libDirectory}(/.*)?'			|| :
/usr/sbin/semanage fcontext -a -t tmp_t				'%{tmpDirectorySrv}(/.*)?'		|| :
/sbin/restorecon -R %{xymonServerRoot}/cgi-* %{wwwCacheDirectory} %{runDirectory} %{libDirectory} %{tmpDirectorySrv} || :

for selinuxvariant in %{selinux_variants}; do
    /usr/sbin/semodule -s ${selinuxvariant} -i %{_datadir}/selinux/${selinuxvariant}/%{serverName}.pp &> /dev/null || :
    /usr/sbin/semodule -s ${selinuxvariant} -i %{_datadir}/selinux/${selinuxvariant}/%{clientName}.pp &> /dev/null || :
done
if [ "$1" -eq 1 ]; then
    /usr/sbin/setsebool -P httpd_can_network_connect on 2>/dev/null || :
fi
%endif


# add unit file or init script; restart if already running
%if %{with systemd}
%systemd_post xymonlaunch.service
%else
/sbin/chkconfig --add %{serverName}
/sbin/service %{serverName} condrestart >/dev/null 2>&1 || :
%endif

/sbin/service httpd status >/dev/null 2>&1 && /sbin/service httpd graceful >/dev/null 2>&1 || :



###################################################################
%post client
# handle upgrades prior to 4.3.10-10 (logfetch status files)
  mv -f %{tmpDirectoryCli}/logfetch.*status %{xymonClientRoot}/logs/ 2>/dev/null || :

%if %{with selinux}
for selinuxvariant in %{selinux_variants}; do
    /usr/sbin/semodule -s ${selinuxvariant} -i %{_datadir}/selinux/${selinuxvariant}/%{clientName}.pp &> /dev/null || :
done
%endif

# Must be able to read /var/log/messages to be effective
%if %{with facl}
setfacl -m u:xymon:r "%{_localstatedir}/log/messages"
%endif
%if %{with logreader}
chgrp "%{logReaderGroup}" "%{_localstatedir}/log/messages"
chmod g+r "%{_localstatedir}/log/messages"
%endif


# add unit file or init script; restart if already running
%if %{with systemd}
%systemd_post xymonlaunch.service
%else
/sbin/chkconfig --add %{clientName}
/sbin/service %{clientName} condrestart >/dev/null 2>&1 || :
%endif


###################################################################
%verifyscript
SUCMD=su
test -x /sbin/runuser && SUCMD=/sbin/runuser
for this in "%{_localstatedir}/log/messages"; do
    echo -n "Checking for read privileges in $this... "
    if ! $SUCMD -s /bin/sh xymon -c "test -r $this"; then
	echo "failed"
	echo "The xymon user needs read privileges for $this" >&2
	%if %{with facl}
	echo "Try: setfacl -m u:xymon:r $this" >&2
	%endif
	%if %{with logreader}
	echo "Try: change its group to '%{logReaderGroup}' and provide group read permissions" >&2
	%endif
    else
	echo "ok"
    fi
done

%verifyscript client
SUCMD=su
test -x /sbin/runuser && SUCMD=/sbin/runuser
for this in "%{_localstatedir}/log/messages"; do
    echo -n "Checking for read privileges in $this... "
    if ! $SUCMD -s /bin/sh xymon -c "test -r $this"; then
	echo "failed"
	echo "The xymon user needs read privileges for $this" >&2
	%if %{with facl}
	echo "Try: setfacl -m u:xymon:r $this" >&2
	%endif
	%if %{with logreader}
	echo "Try: change its group to '%{logReaderGroup}' and provide group read permissions" >&2
	%endif
    else
	echo "ok"
    fi
done


###################################################################
%preun
if [ "$1" -eq 0 ]; then

%if %{with systemd}
%systemd_preun xymonlaunch.service
%else
   /sbin/service %{serverName} stop >/dev/null 2>&1	|| :
   /sbin/chkconfig --del %{serverName}			|| :
%endif

fi

%postun
if [ "$1" -eq 0 ]; then
   %if %{with selinux}
   /usr/sbin/semanage fcontext -d -t tmp_t			'%{tmpDirectorySrv}(/.*)?' 2>/dev/null || :
   /usr/sbin/semanage fcontext -d -t httpd_cache_t		'%{wwwCacheDirectory}(/.*)?' 2>/dev/null || :
   /usr/sbin/semanage fcontext -d -t initrc_var_run_t		'%{runDirectory}(/.*)?' 2>/dev/null || :
   /usr/sbin/semanage fcontext -d -t httpd_sys_script_exec_t	'%{xymonServerRoot}/cgi-bin(/.*)?' 2>/dev/null || :
   /usr/sbin/semanage fcontext -d -t httpd_sys_script_exec_t	'%{xymonServerRoot}/cgi-secure(/.*)?' 2>/dev/null || :
   /usr/sbin/semanage fcontext -d -t httpd_sys_content_t	'%{libDirectory}(/.*)?' 2>/dev/null || :
   for selinuxvariant in %{selinux_variants}; do
     /usr/sbin/semodule -s ${selinuxvariant} -r %{clientName} &> /dev/null || :
     /usr/sbin/semodule -s ${selinuxvariant} -r %{serverName} &> /dev/null || :
   done
   %endif
   /bin/true
fi

%if %{with systemd}
%systemd_postun_with_restart xymonlaunch.service
%endif

%preun client
if [ "$1" -eq 0 ]; then

%if %{with systemd}
%systemd_preun xymonlaunch.service
%else
   /sbin/service %{clientName} stop >/dev/null 2>&1	|| :
   /sbin/chkconfig --del %{clientName}			|| :
%endif

fi

%postun client
if [ "$1" -eq 0 ]; then
   %if %{with facl}
   setfacl -x u:xymon %{_localstatedir}/log/messages	|| :
   %endif
   %if %{with selinux}
   for selinuxvariant in %{selinux_variants}; do
     /usr/sbin/semodule -s ${selinuxvariant} -r %{clientName} &> /dev/null || :
   done
   %endif
   /bin/true
fi

%if %{with systemd}
%systemd_postun_with_restart xymonlaunch.service
%endif


###################################################################
%if %{with extraclients}
###################################################################
#######################################
%pre client-passive
# check for upgrade from < 4.3.0
if [ -r "%{_sysconfdir}/sysconfig/%{clientName}" ] ; then
   if [ "`grep -c ^HOBBITSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -gt 0 -a \
	"`grep -c ^XYMONSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -eq 0 ]
   then
	sed -e 's/^HOBBITSERVERS=\(.*\)$/XYMONSERVERS=\1\nHOBBITSERVERS=\1/' -i %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null
   fi
fi
%if %{with selinux}
for selinuxvariant in %{selinux_variants}; do
  /usr/sbin/semodule -s ${selinuxvariant} -i %{_datadir}/selinux/${selinuxvariant}/%{clientName}.pp &> /dev/null || :
done
%endif


#######################################
%pre client-core
# check for upgrade from < 4.3.0
if [ -r "%{_sysconfdir}/sysconfig/%{clientName}" ] ; then
   if [ "`grep -c ^HOBBITSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -gt 0 -a \
	"`grep -c ^XYMONSERVERS= %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null`" -eq 0 ]
   then
	sed -e 's/^HOBBITSERVERS=\(.*\)$/XYMONSERVERS=\1\nHOBBITSERVERS=\1/' -i %{_sysconfdir}/sysconfig/%{clientName} 2>/dev/null
   fi
fi


#######################################
%postun client-passive
%if %{with selinux}
for selinuxvariant in %{selinux_variants}; do
  /usr/sbin/semodule -s ${selinuxvariant} -r %{clientName} &> /dev/null || :
done
%endif
/bin/true


#######################################################################
%endif
#######################################################################



%files
%defattr(-,root,root)
%doc README README.CLIENT README.* *.terabithia Changes* COPYING CREDITS RELEASENOTES
%doc client/README-local client/README-sections
%doc xymoncgimsg.conf
%doc %{wwwStaticDirectory}/help/manpages/*
%doc %{wwwStaticDirectory}/help/manpages/*/*

%if %{with selinux}
%doc SELinux/%{serverName}.te
%doc SELinux/%{clientName}.te
%{_datadir}/selinux/*/%{serverName}.pp
%{_datadir}/selinux/*/%{clientName}.pp
%endif


%if %{with systemd}
%attr(644,root,root)	%{_unitdir}/xymonlaunch.service
%attr(644,root,root)	%{_presetdir}/98-xymonlaunch.preset
%else
%attr(755,root,root)	%{_initrddir}/%{serverName}
%endif

# Initscript config is under xymonlaunch now
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/xymonlaunch
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{serverName}


%attr(-,root,root)	%{_libexecdir}/%{serverName}
%dir			%{_sysconfdir}/%{serverName}
%dir			%{_sysconfdir}/%{serverName}/ext
%dir			%{_sysconfdir}/%{serverName}/certs
%dir			%{_sysconfdir}/%{serverName}/*.d
%config(noreplace)	%{_sysconfdir}/%{serverName}/*.d/*
%config(noreplace)	%{_sysconfdir}/%{serverName}/*.cfg
%config(noreplace)	%{_sysconfdir}/%{serverName}/columndoc.csv
%config(noreplace)	%ghost	%attr(644,root,root)	%{_sysconfdir}/%{serverName}/xymonpasswd
%config(noreplace)	%ghost	%attr(644,root,root)	%{_sysconfdir}/%{serverName}/xymongroups
%if %{with snmp}
%config(noreplace)	%ghost	%attr(644,root,root)	%{_sysconfdir}/%{serverName}/snmphosts.cfg
%endif

%attr(755,xymon,xymon)	%{libDirectory}
%attr(755,xymon,xymon)	%{logDirectory}
%attr(755,xymon,xymon)	%{runDirectory}
%attr(755,xymon,xymon)	%{wwwDirectory}
%attr(755,apache,apache) %dir %{wwwCacheDirectory}
%attr(755,apache,apache) %dir %{libDirectory}/configs
%attr(755,apache,apache) %ghost %{libDirectory}/configs/critical.cfg*

%attr(-,root,root) %dir %{webDirectory}
%attr(-,root,root) %config(noreplace) %{webDirectory}/*
%attr(-,root,root)	%{wwwStaticDirectory}

%attr(-,root,root) %dir	%{xymonServerRoot}
%attr(-,root,root)	%{xymonServerRoot}/server
%attr(-,root,root)	%{xymonServerRoot}/client
%attr(-,root,root)	%{xymonServerRoot}/cgi-bin
%attr(-,root,root)	%{xymonServerRoot}/cgi-secure

%if %{without trunk}
%attr(755,root,root)	%{_sysconfdir}/%{serverName}/ext/xymonnet-again.sh
%endif

%attr(644,root,root) %config(noreplace)	%{_sysconfdir}/httpd/conf.d/xymon.conf


%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man*/*

### client stuff ###

%attr(-,root,root)		%{xymonClientRoot}
%attr(-,root,root)		%{_libexecdir}/%{clientName}


%attr(644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{clientName}
%attr(644,root,root) %config(noreplace)	%{_sysconfdir}/%{clientName}/xymonclient.cfg
%attr(644,root,root) %config(noreplace)	%{_sysconfdir}/%{clientName}/clientlaunch.cfg
%attr(644,root,root) %config(noreplace)	%{_sysconfdir}/%{clientName}/localclient.cfg

%dir	%{_sysconfdir}/%{clientName}
	%{_sysconfdir}/%{clientName}/client.d
	%{_sysconfdir}/%{clientName}/ext

### end client stuff ###


%files client
%defattr(-,root,root)
%doc README README.CLIENT README.* *.terabithia Changes* COPYING CREDITS RELEASENOTES
%doc client/README-local client/README-sections
%if %{with selinux}
%doc SELinux/%{clientName}.te
%{_datadir}/selinux/*/%{clientName}.pp
%endif

%{_bindir}/bb
%{_bindir}/bbcmd
%{_bindir}/logfetch
%{_bindir}/msgcache
%{_bindir}/xymon
%{_bindir}/xymoncfg
%{_bindir}/xymoncmd
%{_bindir}/xymondigest
%{_bindir}/xymongrep
%{_sbindir}/xymonlaunch

%{_mandir}/man1/bb.1.gz
%{_mandir}/man1/bbcmd.1.gz
%{_mandir}/man1/logfetch.1.gz
%{_mandir}/man8/msgcache.8.gz
%{_mandir}/man1/xymon.1.gz
%{_mandir}/man1/xymoncfg.1.gz
%{_mandir}/man1/xymoncmd.1.gz
%{_mandir}/man1/xymondigest.1.gz
%{_mandir}/man1/xymongrep.1.gz
%{_mandir}/man8/xymonlaunch.8.gz
%{_mandir}/man5/clientlaunch.cfg.5.gz
%{_mandir}/man5/xymonclient.cfg.5.gz


### client stuff ###
%if %{with systemd}
%attr(644,root,root)	%{_unitdir}/xymonlaunch.service
%attr(644,root,root)	%{_presetdir}/98-xymonlaunch.preset
%else
%attr(755,root,root)	%{_initrddir}/%{clientName}
%endif

# Initscript config (and logrotate control) is under xymonlaunch now
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/xymonlaunch
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{clientName}


%attr(-,root,root)		%{xymonClientRoot}
%attr(-,root,root)	%dir	%{_libexecdir}/%{clientName}

%attr(-,root,root)		%{_libexecdir}/%{clientName}/bb
%attr(-,root,root)		%{_libexecdir}/%{clientName}/bbcmd
%attr(-,root,root)		%{_libexecdir}/%{clientName}/logfetch
%attr(-,root,root)		%{_libexecdir}/%{clientName}/msgcache
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymon
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymoncfg
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymoncmd
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymondigest
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymonlaunch

%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymonclient.sh
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymonclient-linux.sh


%attr(644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{clientName}
%attr(644,root,root) %config(noreplace)	%{_sysconfdir}/%{clientName}/xymonclient.cfg
%attr(644,root,root) %config(noreplace)	%{_sysconfdir}/%{clientName}/clientlaunch.cfg
%attr(644,root,root) %config(noreplace)	%{_sysconfdir}/%{clientName}/localclient.cfg

%dir	%{_sysconfdir}/%{clientName}
	%{_sysconfdir}/%{clientName}/client.d
	%{_sysconfdir}/%{clientName}/ext

%attr(755,xymon,xymon)	%{logDirectory}
%attr(755,xymon,xymon)	%{runDirectory}
### end client stuff ###



################ start extra clients ################
%if %{with dietlibc}
%files client-static
%defattr(-,root,root)
%doc COPYING CREDITS RELEASENOTES
%{_bindir}/logfetch.static
%{_bindir}/msgcache.static
%{_bindir}/xymon.static
%{_bindir}/xymoncfg.static
%{_bindir}/xymoncmd.static
%{_bindir}/xymondigest.static
%{_bindir}/xymongrep.static
%{_sbindir}/xymonlaunch.static

%{_mandir}/man1/logfetch.static.1.gz
%{_mandir}/man8/msgcache.static.8.gz
%{_mandir}/man1/xymon.static.1.gz
%{_mandir}/man1/xymoncfg.static.1.gz
%{_mandir}/man1/xymoncmd.static.1.gz
%{_mandir}/man1/xymondigest.static.1.gz
%{_mandir}/man1/xymongrep.static.1.gz
%{_mandir}/man8/xymonlaunch.static.8.gz

%attr(-,root,root)		%{_libexecdir}/%{clientName}/logfetch.static
%attr(-,root,root)		%{_libexecdir}/%{clientName}/msgcache.static
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymon.static
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymoncfg.static
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymoncmd.static
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymondigest.static
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymongrep.static
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymonlaunch.static

%endif



%if %{with extraclients}
%files client-passive
%defattr(-,root,root)
%doc README README.CLIENT README.* *.terabithia Changes* COPYING CREDITS RELEASENOTES
%doc client/README-local client/README-sections
%if %{with selinux}
%doc SELinux/%{clientName}.te
%{_datadir}/selinux/*/%{clientName}.pp
%endif

%{_mandir}/man1/bb.1.gz
%{_mandir}/man1/bbcmd.1.gz
%{_mandir}/man1/logfetch.1.gz
%{_mandir}/man1/xymon.1.gz
%{_mandir}/man1/xymoncfg.1.gz
%{_mandir}/man1/xymoncmd.1.gz
%{_mandir}/man1/xymondigest.1.gz
%{_mandir}/man1/xymongrep.1.gz
%{_mandir}/man5/xymonclient.cfg.5.gz


%{_bindir}/bb
%{_bindir}/bbcmd
%{_bindir}/logfetch
%{_bindir}/xymon
%{_bindir}/xymoncfg
%{_bindir}/xymoncmd
%{_bindir}/xymondigest
%{_bindir}/xymongrep

%attr(755,root,root) %dir	%{_libexecdir}/%{clientName}
%attr(-,root,root)		%{_libexecdir}/%{clientName}/bb*
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymon
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymoncfg
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymoncmd
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymondigest
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymongrep
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymonclient.sh
%attr(-,root,root)		%{_libexecdir}/%{clientName}/xymonclient-linux.sh

%{xymonClientRoot}
%exclude %{xymonClientRoot}/logs

%dir		   %{_sysconfdir}/%{clientName}
%config(noreplace) %{_sysconfdir}/%{clientName}/xymonclient.cfg
%config(noreplace) %{_sysconfdir}/%{clientName}/localclient.cfg
%config(noreplace) %{_sysconfdir}/sysconfig/%{clientName}

%if %{with logreader}
%attr(2711,root,%{logReaderGroup})  %{_bindir}/logfetch
%attr(2711,root,%{logReaderGroup})  %{_libexecdir}/%{clientName}/logfetch
%else
%attr(755,root,root)	%{_bindir}/logfetch
%attr(755,root,root)	%{_libexecdir}/%{clientName}/logfetch
%endif


%files client-core
%defattr(-,root,root)
%doc README README.* *.terabithia README.core Changes* COPYING CREDITS RELEASENOTES

%{_mandir}/man1/bb.1.gz
%{_mandir}/man1/bbcmd.1.gz
%{_mandir}/man1/xymon.1.gz
%{_mandir}/man1/xymoncfg.1.gz
%{_mandir}/man1/xymoncmd.1.gz
%{_mandir}/man1/xymondigest.1.gz

%{_bindir}/bb
%{_bindir}/bbcmd
%{_bindir}/xymon
%{_bindir}/xymoncfg
%{_bindir}/xymoncmd
%{_bindir}/xymondigest
%{_libexecdir}/%{clientName}/bb
%{_libexecdir}/%{clientName}/bbcmd
%{_libexecdir}/%{clientName}/xymon
%{_libexecdir}/%{clientName}/xymoncfg
%{_libexecdir}/%{clientName}/xymoncmd
%{_libexecdir}/%{clientName}/xymondigest
%dir %{_libexecdir}/%{clientName}

# Still need to know where to send data
%dir		   %{_sysconfdir}/%{clientName}
%config(noreplace) %{_sysconfdir}/%{clientName}/xymonclient.cfg
%config(noreplace) %{_sysconfdir}/sysconfig/%{clientName}

# $XYMONCLIENTHOME
%dir %{xymonClientRoot}
     %{xymonClientRoot}/bin
     %{xymonClientRoot}/etc


%files client-orca
%defattr(-,root,root)
%doc README Changes* COPYING CREDITS RELEASENOTES
%{_libexecdir}/%{clientName}/orcaxymon
%{_mandir}/*/orcaxymon.*
%endif

################ end extra clients ################


# TODO: add XYMONEXNETWORKS support to xymongrep
# TODO: dietlibc broken since client now requires IPC support -- needs -lcompat
# TODO: 'hostsnap' command
# TODO: log timing on long xymondboard queries
# TODO: support '\n\v[' client seperator
# TODO: store last cookie in xymond for use by xymond_alert + scripts Recovery messages
# TODO: --reportaddr= for xymonnet/xymongen/xymonproxy as override for XYMONSERVER
# TODO: sqlite3 locally built (RHEL5 system version too old for trunk)
# TODO: perf test http://symas.com/mdb/
# TODO: xymongen: add clientdata/info/trends links after hostnames
# TODO: ignore color of incoming trends dots for status messages
# TODO: findhost.c -> use hostinfo command instead of loading hosts.cfg ourselves
# TODO: xymonlaunch: verify ONHOST & DISABLED work properly


# full extcombo logic in xymonproxy? Need to break apart retry logic, etc.
# green->clear for msgs when see strings like 'Cannot open logfile /var/log/messages : Permission denied'
# msgs -> rewrite "Full log" line for clarity
# don't bail on rrd dupe "ncv" data in a single session
# multiple rrds on a single status page? ("cpu=la,vmstat2")
# GAUGE seen as DERIVE during SPLITNCV? getting spurious "not an integer" errors
# semaphore timing on xymond_channel? xymond_rrd shouldn't be slowing down xymond but does?

## Error: xymonnet egocolumn not transmitting when sent via TCP and then BFQ

%changelog
* Thu Jan 09 2014 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-1
- update to release 4.3.13
- rpmlint: remove .orig file from /docs/
- selinux: fix RPM macros for F20
- systemd: add 'preset' file so service aliases work
- initscript: client now matches server script
- add makefile xargs patch
- remove upstreamed patches:
  xymon.rrd_pipe.patch
  xymon.4313-tlsv1.patch

* Tue Dec 17 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.27.1
- eliminate one compiler warning in gcc 4.8

* Mon Dec 16 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.27
- xymonproxy.c: --bfq fixes
- xymon.c: print warning when assuming localhost recipient
- systemd: xymon.service -> xymonlaunch.service
- systemd/sysv: configure xymonlaunch log file dest in /etc/sysconfig/xymonlaunch
- sysv: use xymoncmd here too
- rpmlint: re-ghost xymonpasswd file on new install
- logreader group: if enabled, append supplementary group (don't replace)
- less verbose hostinfo debugging

* Tue Dec 10 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.25
- enable SENDHUP for xymond/xymonproxy in tasks.cfg for logrotation (F18+)
- use apache 2.4-compatible snippets in 2.4 systems (F18+)
- experimental --bfq option to xymonproxy
- add docs for various patches: modify-valid, SENDHUP
- bump sqlite to 3.8.2
- fix the 'stale' alert patch (maybe?)
- add TLSv1 patch

* Thu Dec 05 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.24
- add XYMONEXNETWORKS support to exclude NET: tags from xymonnet
- xymond_rrd: don't die from SIGPIPE when an external processor goes away

* Wed Nov 27 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.21.1
- really fix the systemd service unit file

* Wed Nov 27 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.21
- xymonlaunch: log file now set in /etc/sysconfig/xymon* instead of
  the init script itself. SysV systems have default set in init.d, 
  systemd systems have no default and will go to syslog.
- support proper systemd install/upgrade scriptlets
- fix some f19 compile warnings

* Wed Nov 27 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.19.8
- xymond_alert: send "recovery" message out for stale alerts before dropping
- tag error messages from xymonlaunch/xymond_channel in worker logs
- reduce debug verbosity in hostinfo
- include sample xymoncgimsg apache config snippet
- include xymon.service file for systemd (F18+)
- remove "ghost" from xymonpasswd file to ensure httpd works on install

* Tue Nov 26 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7316.19.6
- update to trunk 7316 (image type)
- fix to xymonrrd.c in 7316 preventing compile
- fix multiple modifiers from xymond_rrd overwriting each other
- increase STATUSMODE sleep to 4s

* Thu Nov 21 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.19.5
- rebuild on RHEL 6.5 (rebased openssl pkg)

* Wed Nov 20 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.19.4
- can specify number of subsequent status messages a modify state can override
- accept large cookies on 64bit systems
- xymond: log when closing connection due to timeout

* Mon Nov 18 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.19.3
- xymond_alert: bail out if can't connect to xymond to compare checkpoint
- xymonproxy: increase max number of servers to 5
- xymonnet: add debug output to dependency processing
- add 1s sleep when STATUSMODE set to prevent submission race condition
- restore some ancient RPM changelog history
- update sqlite to 3080100

* Mon Oct 14 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.19
- log, but not a xymonnet err, when host lookup failures occur

* Wed Oct 09 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.18
- change content-type of HTTP response to text/plain
- prevent HTTP 500 errors when given blank submission
- add feature docs to sysconfig/xymon-client
- minor tuning in clientconfig retrieval

* Wed Oct 02 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.17
- add HWPREDICT to default rrddefinitions.cfg
- xymond_rrd: bail if rrddefinitions.cfg has no default stanza
- client: when STATUSMODE enabled, fork individual xymon commands to 
  each destination in $XYMSERVERS

* Thu Sep 26 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.16
- modify internal timeout flag value to allow for timeouts of 0
- $XYMON_RETRIES environment variable used (default: 2)
- client: $XYMCONFIGSRV support when STATUSMODE is on

* Wed Sep 25 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.13-0.7314.15
- new version format for 4.3.13 branch
- add systemd support to .spec file (F18+)
- fix wrong result in sendmsg for halfway open connections
- NOTE: if using bfq submission, use /usr/libexec/xymon/xymon on server

* Thu Sep 19 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-14
- honor maxmsgspercombo even when using bfq
- banner bug fixes in xymonnet

* Wed Sep 18 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-13.4.5
- ensure 64bit safe strbuffers now that we're using larger extcombos

* Wed Sep 18 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-13.4.3
- fix: check for allocation failure in dupstrbuffer
- debug extcombo size flushing

* Wed Sep 18 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-13.3
- fix some compile warnings on F19
- init: we don't actually need xymonlaunch to make a pid file
- add --bfq/--no-bfq support to xymond_client / xymond_rrd / xymonnet

* Wed Sep 11 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-13
- shm msg queue key can be 0

* Sat Sep 07 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-12.4
- faster debug print short circuit
- add ipcs info to client report
- report errors in bfq id generation
- bfq size/allocation debugging
- xymond.c: increase bf_bufsz to a size_t here too

* Wed Sep 04 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-12.1
- update trunk to 7312
- use memmove instead of memcpy now that we're actually using large
  buffers in combo_add

* Tue Sep 03 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-12
- update trunk to 7310
- update sqlite to 3080002

* Sat Aug 31 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-11.2
- 4.3.x: add missing modify and hostinfo to xymond_stats
- distinguish message timeouts from bogus/unknown commands in xymond_stats
- specify relevant channel id on certain xymond errors

* Thu Aug 29 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-11
- trunk: update sqlite ver to 3080001

* Wed Aug 28 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-10.2
- add XYMONRUNDIR to environ.c
- fix moarextcombo bug in rrd
- trunk: bump included sqlite ver to 3080000

* Mon Aug 26 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-10
- bump to 7306
- upstream bfq patches / split moarcombo for rrd

* Sat Aug 24 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-9
- bump to 7301
- remove 2 upstreamed patches
- reduce default bfqchunk size to 50; make environment tuneable
- don't include /etc/sysconfig/xymon-client in xymonserver.cfg

* Tue Aug 20 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-8.1
- use proper max_backfeedsz
- reduce default tcpcheckinterval to 1s

* Tue Aug 20 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-8
- bump trunk/branch release number
- fixes in clientparse / combo_addchar / tcpcheckinterval patches
- query XYMONDTCPINTERVAL env variable for tcpcheckinterval
- propagate errors from xymon back to xymonlaunch in logfetchupdate

* Mon Aug 19 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-7
- try to cope with malformed status/client messages more
- re-add client sempahore proceed anyway patch
- increase bf_bufsz to size_t (msglen_t fix)

* Mon Aug 19 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-6
- update trunk to 7295
- extend client "status" message syntax to include ostype/class
- add STATUSMODE to xymonclient.sh and add logfetchupdate scripts
- make location of modify override line display consistent

* Sat Aug 17 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-3.9.1
- fix do_rrd reporting

* Fri Aug 16 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-3.9
- update trunk to 7283
- use bfq in xymonnet's report column
- use bfg and extcombo messages in do_rrd.c
- respect XYMON_TIMEOUT across the board in sendmsg.c for reals
- fix double-init of hostinfo in xymond_rrd.c

* Wed Aug 14 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-3.7
- update trunk to 7280
- update trunk combodata and clientconfig patches to match
- don't use msglen_t in 4.3.13+, since it doesn't exist in dietlibc

* Tue Aug 06 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-3.5
- trunk/branch update to 7255
- fix "client " pseudo-status client messages creating fake test recs

* Sun Aug 04 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-3.1
- shorten semaphore alarms to 1s on both channels and workers
- branch fixes to xymond_client combo calls

* Wed Jul 31 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-3
- trunk update to 7250
- branch rpm update to 4.3.13 (7250)
- fix: dual log rotation when HUP given
- xymond: don't attempt to continue if shm already taken
- split xymonproxytune, xymondlogging into two patches
- major .spec file work

* Fri Jul 26 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-2
- cleaned up RPM readme and changes files slightly
- xymond_client.c: don't wait forever to flush combo when timeout not given
- fix segfault in malformed client messages masq. as status messages
- add clientconfig support to xymon.c

* Fri Jul 26 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-1
- properly count combodata messages
- clientconfig command

* Thu Jul 25 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.12-0.3
- updated to version 4.3.12
- heavier debugging in loadhosts.c:hostinfo and xymond_client.c
- sendmsg: combodata support
- sendmsg: honor $XYMON_TIMEOUT if in environment
- xymond: fix combodata patch
- xymond_client: combine data messages together as "combodata"
- remove the following upstreamed/mooted patches:
  - xymon.msgtimeout.patch
  - xymon.nokilllocchildren.patch
  - xymon.sco_sv.patch
  - xymon.loadhosts_vpage.patch
  - xymon.missingdropchns.patch
  - xymon.linux-ifconfig-stderr.patch
  - xymon.freebsd-clockstr.patch
  - xymon.psalign.patch
  - xymon.ipad.patch
  - xymon.lqueue.patch
  - xymon.rrdclearok.patch
  - xymon.contest_errors.patch
  - xymon.croninterval.patch
  - xymon.rrdnospace_take2.patch
  - xymon.sendmsgdbg.patch
  - xymongen-4311.diff
  - xymon_trunk.reportline.patch
  - xymon_trunk.eolchar.patch
  - xymon.snmp-compile-warns.patch
  - xymon.norrd.patch
  - xymon.shell.patch
  - xymon.generic_client.patch
  - xymon.cmdnl.patch
  - xymon.loadhosts-lgbuf.patch
  - xymon.includetabsok.patch
  - xymon.cmdhostname.patch
  - xymon.channelfilterenv.patch

* Tue Jul 23 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-12
- xymon.c: honor $XYMON_TIMEOUT if in environment and timeout not specified
- even more debugging code in xymond_client
- experimental combodata, hostsnap, senderstats commands
- Fedora: re-enable hardened build

* Sat Jul 20 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-11
- run local client on server by including clientlaunch.cfg on new installs
- split xymon.resetfails.patch into two patches
- add DELAY (after NEEDS launched) and SENDHUP options to tasks.cfg syntax
- add (existing) vmstat1-5 graphs into the trends page

* Sat Jul 20 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-10.4.5
- check for attempts to drop dirs up a path
- xymond_client: add --flushtimeout option to delay combo msg sends
- xymond_client: load hostinfo (if needed) before getting the next message
- client/linux.c: more debug lines
- weekly logrotate.conf snippet
- remove getenv from xymonproxy which can segfault under high load when
  multithreaded and stack enforcement is on
- disable hardened build (performance)

* Wed Jul 17 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-10.4.1
- actually apply the psalign patch
- fix CSS to work with iPad hover tags
- add --lqueue option to xymond
- xymond_rrd: swap blue and clear logic; parse clear, ignore blue
- xymond_rrd: load host config prior to connecting socket
- Remove netstat pid patch (unprivileged users don't get useful info)

* Mon Jul 08 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-10.2
- Fix broken clock test in freebsd (reported by Eddie Stassen)
- Fix some incorrect DoWs in the changelog
- Fix gcc 4.8 and dietlibc warnings
- Fix rcsid warning in xymon-snmpcollect.c
- Fix warning in filtering patch
- Move some stuff around in the .spec file
- trunk: Forward port timefunc.null

* Fri Jun 14 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-10.1
- fix 5m -> 100s update in clientlaunch.cfg, which broke at some point

* Tue Jun 11 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-10
- fix generic client patch to not leave 0-byte file in src
- send ifconfig stderr to /dev/null on linux (need to move stats to ip)
- add vmstat -s section on Linux client
- fix missing cast in epoch_hist patch
- minor patch cleanup

* Mon Jun 10 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-9.1
- add /proc/meminfo section on Linux client
- fix improper var init in msgtimeout.patch

* Sat Jun 08 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-9
- send drop/rename commands to clichg/user channels
- add noprefer hosts.cfg directive

* Tue May 28 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-8.1
- add xymon.psalign.patch (orig by Christoph Schug, pointed out by
  Jeremy Laidman)

* Thu May 23 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-8
- update sqlite in trunk to 3.7.17

* Mon May 20 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-7.1
- fix availabiity logs link in uptime reports when using epochhist

* Sat May 18 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-7
- backport xymon.downtimecolor.patch
- update c-ares version to 1.10.0 (trunk and release) and
  deal with the CFLAGS/CPPFLAGS mess
- add xymon.loaddatanull.patch
- back out stachg histsync patch
- restore localclient.cfg and xymongrep into client package

* Thu May 09 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-6
- don't flood xymond_history on restart unless a status is different
- check for debug status before calling dbgprintf in a few more places
- increase the length of time xymond will keep around "stale" client
  sub-messages to match the default purple expire time
- add debug code in find_cookie
- add missing newline in clientcountwarn patch
- increase xymond starting and incremental buffer size from 128/32
  to 256/256

* Mon May 06 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-5.1
- really fix the vpage/vsubpage/vsubparent parsing

* Fri May 03 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-5
- backport memory size overflow on SCO OS with large amounts of ram
- fix vertical page/parent/subparent path and title storage
- refer to msgs test as "Log files" rather than "System logs"
- fix xymond_channel filter flag not being set
- add --delay option for xymond_channel between initial fork
  of child process and registering via IPC with xymond
- restore xymoncfg to client rpms

* Mon Apr 29 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-4
- start xymond_channel worker process before registering with IPC
- fix bug where running daemons in --locator mode could accidentally
  take down xymonlaunch
- add --unknownclientosok option to xymond_client
- add --msgtimeout option to xymond_channel
- actually include the static www apache snippet change
- init files now use xymonlaunch as the name for subsys locking
- revert to file when the HOSTSCFG variable actually matches
- background the final cache flush when xymond_rrd is closing out
- don't complain about message sequence gaps when xymond_channel is
  known to be filtering messages before we get them

* Mon Apr 22 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-1
- ensure static www directory is set readable in apache snippet
- fully support reading hist files regardless of EPOCHHIST
- selinux fixes for fedora 18
- remove patches upstreamed in trunk 7194
- add xymongen-4311.diff


* Sun Apr 21 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.11-0.2
- update to 4.3.11
- remove various backported patches
- fix dietlibc warning in build/test-endianness
- spec file cleanups

* Sat Apr 20 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-9.4.1
- hide stderr in upgrade scriptlet
- use upstream loadhosts-prefer-speedup.diff

* Thu Apr 18 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-9.4
- backport 5 fixes from 4.3.11
- tab whitespace accepted after include and directory lines in configs
- xymoncmd checks and uses HOSTNAME if set before forking uname -n
- fix some dietlibc warnings (mainly spurious fflushes)
- add strncasecmp to functs checked for strings.h add in dietlibc
- move checkpoint files to the proper location during upgrades
- wrap epoch history filenames in EPOCHHIST var

* Tue Apr 16 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-9.3
- move checkpoint files to non-rundir storage (thanks Tom Diehl)
- move client logfetch .status files to logfile storage
- add pids to netstat output on linux clients
- set PREFEREARLIER env var to ignore 'prefer' tags reading hosts.cfg
- set HTTPRRDCOLNAME to force xymonnet to write http URLs with custom column
  names to rrd files under those names instead (use if you suspect you'll
  be changing URLs but want to keep the data sets the same)

* Mon Apr 15 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-9.2.4
- fix improper initscript 'status' exit code when xymonlaunch not running
  (thanks Scott Stone)
- update sqlite in trunk to 3.7.16.2
- xymongen: ignore 'prefer' tag in hosts.cfg -- assume earlier lines are 
  more preferred -- to prevent linear scans of host tree
- increase status report ttl for xymond/xymonproxy from 6 to 11m

* Sat Mar 23 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-9.2.1
- strip trailing newlines from SERVEROSTYPE/CONFIGCLASS if not set
- add timing code to loadhosts.c for debugging
- xymongen: don't go yellow if runtime was longer than a 
  non-existant interval (eg, via crondate)
- don't make flap detection trigger a yellow color for the xymond test

* Tue Feb 19 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-9
- add generic client tester for files/logs/msgs monitoring

* Thu Feb 14 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-8.5
- rotate logs via xymonlaunch HUP
- change logrotate from weekly to daily
- fix the do_rrd.c fix
- xymond: don't send @@logrotate on HUP

* Fri Feb 01 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-8
- updated fix for tree crash
- fix segfault in do_rrd.c (reported by Nicolas LOYAU)
- fix missing rundir definition in xymonclient.cfg
- fix warnings in timefunc.c on F18
- pay attention to xymonlaunch log file env variable in xymond_sample
- wait longer after starting a dependency before starting tasks that
  list them as 'needs' in tasks.cfg
- xymonproxy line1 format now matches xymond
- add 6m ttl for xymonproxy/xymond status tests
- client init script now runs xymonlaunch from /usr/sbin
- slightly more efficient shell/forking in lib/run.c
- remove Provides: xymon-client from xymon, to prevent server-side being
  pulled in accidentally by client-requesting packages
- don't fall back to loading from the local hosts.cfg
  if told to get it from xymond and xymond fails -- just quit
- abort xymonnet if hostlist is empty

* Tue Jan 29 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-6.5.2
- fix off-by-1s error when performing checks for expired tests
- fix typo in sendmsg.c (non-trunk)
- xymond: more verbose logging
- dbgprintf optimization

* Mon Jan 28 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-6.5
- xymond: if SysV memory already found, warn instead of dying
- logprintf function (+timestamp to stdout) added to errprint.c
- clarify that ghosts/multi-src reports are only of those within 
  the last 10m
- xymond_channel: pass HUP to children on receipt
- xymond_channel: pass logfn to children from xymonlaunch

* Fri Jan 25 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-6.3
- null key fix in lib/tree.c
- move symlnks for xymonlaunch and xymond to /usr/sbin/
- get default port for 'bb' in /etc/services also (non trunk)

* Thu Jan 17 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-6
- fix incorrect log time epoch conv shown in historical status pages
- xymond: send cached copies of hosts.cfg until our next reload
  (should improve performance when using many procs loading 
  configs over net simultaneously)
- add standard line1 header for xymond/xymonnet/xymongen reports
- add missing space back to http column name statuses
- add --no-cookies and --no-save-cookies options to xymonnet
- http tests that have a given column name for (e.g.) content tests 
  now are named after that column at rrd time (instead of using the
  full URL). YOU WILL NEED TO RENAME YOUR RRD FILES BY HAND FOR ANY 
  TEST USING THIS FEATURE AFTER UPGRADING TO KEEP/MERGE TCP HISTORY.

* Fri Jan 11 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-5
- revert defaultchk patch
- add strfunc_null patch from Tom Schmidt

* Fri Jan 11 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-4
- add runtime opt var for xymonlaunch to /etc/sysconfig/xymon-client
- really fix the silly segfault in defaultchk patch

* Thu Jan 10 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-3
- dietlibc builds create a parallel client-static RPM
- /usr/bin/xymonlaunch symlink was not included in client RPMs
- zero-pad xymon2.rrd data output (already in trunk)

* Thu Jan 03 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-2.1
- add --no-rrd option for xymond_rrd

* Thu Jan 03 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-2
- don't leave patch debris in the /docs/ directory
- check default locations for checkpoint files (xymond/xymond_alert)

* Wed Jan 02 2013 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-1.71
- daemons don't write pid files out on their own unless specified
- set high timeout value when issuing a 'xymon crashed' alert to give
  xymonlaunch a chance to start xymond back up to receive it.
- updated README.terabithia and CHANGES.terabithia

* Mon Dec 31 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-1.70
- xymonlaunch: handle more logging directly in default config
- xymonlaunch: search more locations for default config
- xymonlaunch: support PIDFILE lines in tasks.cfg
- xymonlaunch: after 10m, no longer delay by 10m if a proc has 
  exited non-zero > MAX_FAIL times since our launch
- xymonnet: don't go yellow if runtime was longer than a 
  non-existant interval (eg, via crondate)
- spec: add ghost entry for /etc/snmphosts.cfg
- fix: some compiler warnings in xymon-snmpcollect
- apply alertcount and rootfs fixes from 4.3.11
- update non-trunk c-ares to 1.9.1

* Sun Dec 23 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-1.5
- more verbose xymonnet logs when weird connection test errors occur
- accept (and write out) epoch TIMEBUFs when selecting history logs
- append protocols.d lookup to correct protocols file

* Fri Nov 16 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-1.1
- binaries were still reporting as 4.3.9

* Mon Aug 06 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.10-1
- update to 4.3.10 release
- removed eight upstreamed patches, updated rundir patch
- note: trunk builds for EL4/EL5 are likely to be unstable due to sqlite
  error handling

* Tue Jul 31 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.9-4
- fix: gcc warning in xymond_filestore mkdir patch
- fix: ifstat not working for F17 (ifstat patch for F17 from John Horne)
- use /sbin/service in logrotate script and redirect output to null
  (thanks Mike Grozak)

* Mon Jul 30 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.9-3.1
- final EL5 SELinux fixes (hopefully!)

* Mon Jul 30 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.9-3
- use upstreamed version of showgraph null tmpdir patch
- SEL: EL5 fix: use httpd_cache_t type for /var/cache/xymon/
- SEL: add var_lib_t to allowed fping output files type
- SEL: fix tmp_t permission on /var/lib/xymon/tmp not being removed
- EL5 x86_64 built on RHEL

* Fri Jul 27 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.9-2
- fix: don't segfault when tmpdir (rundir) is not accessible 
  by showgraph.cgi
- fix: allow compile trunk w/ ssl disabled
- fix: blank XYMONSERVERHOSTNAME value on new server installs
- fix: use list_dir_perms in SELinux for EL5
- fix: don't build EL4 with SELinux
- roll back scope of lber-redux patch
- add contest_oldopenssl, osslinc, notshellscript, and xymoncfg
  from 4.3.10 branch
- require the httpd path rather than the package name (for 7.3)

* Wed Jul 25 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.9-1
- update to 4.3.9
- fix wrong client homedir set on new installs (thanks Colin Coe)
- fix semanage not listed as a Require, leading to files with
  incorrect SELinux contexts if policyutils-python wasn't installed
- don't pre-package client's $XYMONHOME/local directory as 
  /usr/local/share/xymon-client (cf: RHBA-2012:0843-1, BZ#732799)
- remove version >= 3 requirement for fping
- add x509_name patch for building on ancient openssl
- add lber-redux and usrlibs patches for building on el3
- fix pre scriptlet failing with empty if statement
- extraordinarily old versions of sed can't in-place edit, and we're
  already using perl elsewhere, so just use perl...
- remove upstreamed patches:
- .xymsrvoops
- .combostatus
- now rpmlint error free!

* Tue Jul 17 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.8-0.56
- add xymon.combostatus.patch
- upstreamed FPING xymonserver.cfg build patch
- move usr-ldap patch from trunk to 4.3.x

* Mon Jul 16 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.8-0.5
- TEST update release version to 4.3.8, trunk to 7090
- don't chgrp /var/log/messages if --without logreader
- rhel3 support: add --with facl build conditional
- remove largemem patch (only affects new installs)
- remove the following upstreamed patches:
- .sha2
- .nl
- .gcc296
- .dispinclude
- .xymservers
- .crondate
- .rrdnospace
- .closefh
- .string
- .hostsvcinfolinks
- .badhttpnl
- .rrd-sprintf
- .rrdprocessortabs
- .enableinode
- .inode
- .maxmsg
- .clearok
- .normstatlines
- .refreshonerr
- .usermsg
- .adminconfig
- .stderrcgi
- .workerlocatorseq
- .clientbuild (trunk)

* Mon Jul 09 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-26.85
- update trunk to 7018

* Thu Jun 21 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-26.81
- add 'source' and '.' as aliases for 'include' in env config files
  for increased shell compatibility (systemd unit files)

* Mon Jun 11 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-26.1
- fix buffer overflows in rrd processing
- patch updates for trunk
- add 'rotate' option to client init script (thanks Mike Grozak)
  and more init script LSB compliance

* Wed May 23 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-25
- quiet install if xymonserver.cfg doesn't already exist
- single source rpm now contains both trunk and non-trunk patch files
- trunk: gcc 4.7 (F17) compatibility for DSO link changes
- trunk: client now requires zlib and openssl for building
- trunk: ensure configure.client build brings in zlib/ssl
- trunk: dietlibc disabled (static build errors, see BZ 807050)
- rpmlint: add bb and bbcmd man pages as symlinks

* Mon May 14 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-24.2
- print warnings from verify script properly
- print to correct filehandle when CGI freopen() fails
- pathname rewrite for FHS compat
- fix: message seq numbers not incrementing when locator svc used
- remove --no-cache from xymond_rrd

* Sat May 12 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-24
- selinux/rpmlint: loosen permissions on /var/cache/xymon
- selinux/rpmlint: use rundir for rrdctl sockets
- selinux: restrict httpd access to /var/lib/xymon/tmp
- rpmlint: remove unneeded dangling /tmp symlinks
- fix segfault when failing to open cgierror.err
- unless XYMONCGILOGDIR set, send CGI errors to stderr
- adminsenders allowed to download configs (xymond_client needs it)

* Sat May 12 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-23.8
- mark html man pages as documentation
- remove duplicate specification of logdir in server package
- create rundir in init scripts if missing

* Mon May 07 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-23
- CGI-generated files (/rep and /snap) moved to /var/cache/xymon
  for better SELinux control and fewer rpmlint warnings
- /web templates moved to /etc/xymon/web for the same reason
- hosts.cfg man page updated
- 'store' tag in hosts.cfg converted to 'data' and 'datasvc' tags
- cannot be applied to trunk

* Sun May 06 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-22
- reworked recipient patch
- fix duplicate messages sent to localhost by xymond_client
- web templates now marked as config so local changes don't get overwritten
- server package no longer modifies permissions on /var/log/messages
  automatically. (client package is unchanged)

* Wed May 02 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-21.1.1
- strip '\r\n' from bad HTTP error messages instead of '\n'
- update some patches for recent trunks
- xymon can read a message from XYMMSG for use when Bernstein chaining

* Mon Apr 30 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-21
- facls aren't handled by logrotate properly thanks to BZ#666677,
  683622, and 683626; use supplemental adm group for xymon client
- restorecon was not being run on updates, leading to incorrect
  selinux lables on some files
- update xymon.1 manpage for norecip patch
- updated README.redhat
- spec file cleanup

* Fri Apr 27 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-20
- remove xymonping in favor of fping3
- add fping to SELinux policy
- use comprehensive staticwww patch
- no pthreads for client with dietlibc
- missing description for client-orca package

* Fri Apr 27 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-19
- fix missing user channel stats to xymond report
- fix 'notes' messages mishandled in xymond_filestore
- fix 'trends' svc refresh loop when using locator service
- fix rpmlint/selinux: move apache-writable critical.cfg to xymonvar
- tmpfs: move 'notes' and periodic html reports from www to xymonvar
- tmpfs: recreate missing subdirs in www and xymonvar
- tmpfs: specify location of 'help' for xymongen
- add autorefresh to html error pages
- add verifyscript to check xymon facl/read privs on /var/log/messages

* Wed Apr 25 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-18
- compile with -pthread (instead of D_REENTRANT)
- trunk: require fping >= 3.0 and remove tarballed version
- trunk: annotate patch sources
- remove public domain xymon-rclient scripts
- move ocraxymon to optional sub-package

* Fri Apr 20 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-17.3
- correct xymonlaunch.pid location on server
- clear client reports (eg, when no defined procs tests) should be 'ok'
- files/msgs test status lines made like others

* Thu Apr 19 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-17.1
- remove lsb from Requires
- really fix client SELinux policy

* Wed Apr 18 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-16
- patch filename cleanup
- respect all vendor/rpm cflags
- all config files marked noreplace
- dietlibc client binary building now works
- server-side client can run when xymond is off in tasks

* Mon Apr 09 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-15
- on new server installs, configure client for reporting to localhost
- include selinux policy files for client and server
- add selinux context to histlogs directory
- fix crash with blank storehttpdata col name
- remove sgid logfetch in favor of facls

* Thu Apr 05 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-14
- add storehttpdata patch to allow http test data to be saved
- tweak vmstat launch line in client to pipe commands to sh
- merge some spec formating changes from trunk
- add selinux policy from Viliam Pucik
- use facls for syslog permissions instead of a sgid logfetch

* Fri Feb 24 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-13
- add httpheaders patch

* Wed Jan 25 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-12.3
- add xymond-download-closefilehandle.patch
- fix crondate parsing
- fix rrd spacing 
- cleaner vmstat invocation
- update patch references

* Wed Jan 18 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-11.1
- more missing newlines in errprintf statements caught
- move automated reports from cron to xymonlaunch control
- remove Requires for crontabs
- inode 'section' client patched into client script
- sar 'section' client removed
- all configs now marked noreplace
- note: crondate parsing appears broken

* Sat Jan 14 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-9
- include task file for xymon-rclient

* Fri Jan 13 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-8
- patch for two more compile errors on gcc-2.96-113 (RedHat 7.3)
- assume recipients are in the env if not declared on command line
- keep all xymonclient-*.sh scripts on server
- package xymon-rclient on server

* Thu Jan 12 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-7.1
- remove unusued localclient.cfg from --local server invocations
- xymongen was not following dispinclude lines properly
- xymond wasn't following net/disp includes
- disable rrd caching by default -- still not working
- enable inode section checking on linux

* Mon Jan 09 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-6.2
- ensure client symlinks are handled properly during upgrades
- add breakout directories for alerts.d and analysis.d
- because the /var/run/ directory is removed tasks.cfg is NOT marked
  config(noreplace) on servers during this upgrade
- remove inode and mounts patches and replace with section scripts
- sar script included as client extra

* Fri Jan 06 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-5
- logrotate script was looking at an incorrect directory
- replace perl with %%{__perl} -p in scriptlets
- fix lots of rpmlint warnings
- move static HTML (gifs, help, menu) out of /var/www/xymon and
  compress html-ized man pages
- add Default-Start/Stop to init scripts
- use tmpdir for runtime info (F15 compliance for tmpfs /var/run/)

* Wed Jan 04 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-4
- build requires net-snmp-devel for experimental snmp support
- client now installs to /usr/share/xymon-client
- remove all clientupdate and orcaxymon references
- clients don't need xymoncfg installed
- remove unusued client tmp directory
- add 'sections' plugin directory for packaged client scripts

* Tue Jan 03 2012 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-3
- use build conditionals for extra clients, dietlibc, and alt shells
- add /usr/local/share/xymon-client for local pre-fab client scripts
- modify CGI scripts when using alternative shell (eg, /bin/dash)
- rename dfinodes report (from patch) to match what xymond_rrd expects
- fix dietlibc x86_64 builds with updated sha2 libs
- include strings.h when needed
- add upstart flags to init scripts
- remove legacy runclient.sh and xymon.sh startup scripts
- remove unused xymonclient-$os scripts

* Thu Dec 29 2011 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-1
- patch xymond_rrd to delimit stdout streams with tabs
- create combos.d and protocols.d directories for server
- add PIE compilation for security
- add rrd_rec patch for RH7's gcc
- update license to GPLv2
- clean up misc rpmlint warnings

* Tue Dec 13 2011 Japheth Cleaver <cleaver@terabithia.org> 4.3.7-0
- upgrade to 4.3.7

* Mon Nov 07 2011 Japheth Cleaver <cleaver@terabithia.org> 4.3.5-2
- 2 patches were failing due to fuzz being stricter in RHEL6

* Tue Oct 11 2011 Japheth Cleaver <cleaver@terabithia.org> 4.3.5-1
- upgrade to 4.3.5
- bug: xymonrun left trailing DIR in replacement

* Wed Aug 03 2011 Japheth Cleaver <cleaver@terabithia.org> 4.3.4-0
- upgrade to 4.3.4
- remove minor rrd patch until can be re-tested on old rh7.3 box

* Sun May 08 2011 Japheth Cleaver <cleaver@terabithia.org> 4.3.3-0
- upgrade to 4.3.3

* Thu Apr 14 2011 Japheth Cleaver <cleaver@terabithia.org> 4.3.2-0
- upgrade to 4.3.2

* Thu Mar 24 2011 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0-0.959
- add pre-upgrade script to convert client sysconfig to new variable names

* Wed Mar 23 2011 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0-0.958
- remove "-l" in second useradd call (oops)
- clean up several patches that were succeeding due to fuzziness
  but were failing on fedora 14
- add useLogReaderGrp flag in .spec
- add /usr/bin/xymon{,cmd} symlinks in client package
- remove gcc-c++ BuildRequires; seems to no longer be needed

* Fri Mar 18 2011 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0-0.956
- remove "-l" in useradd call (allow legacy rh builds)
- alwaysXYMONSERVERS: don't place localhost into xymonclient.cfg (oops)

* Thu Mar 17 2011 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0-0.955
- update to 4.3.0 release
- several init script typo fixes
- remove sar and yum check scripts (to be packaged separately); also
  remove Requires: perl
- add ghost /etc/xymon/xymon{passwd,groups} files
- replace localhost entries in default hosts.cfg with hostname


* Mon Feb 14 2011 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0-RC1-0.900
- massive spec file cleanup
- update to 4.3.0-RC1, with most files and variables removing
  references to 'hobbit' anywhere
- remove patches integrated upstream
- replacement init scripts now parsed by Makefile with variables
- add upstream xymonreports.sh to cron; Requires: crontabs, logrotate
- /etc/sysconfig/xymon on server is now a ghost config
- rename /etc/xymon-client/launch.d/ to client.d

* Fri Jul 9 2010 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.6
- slight spec file clean up
- hobbitgraph.cfg now broken out into a directory (taken from Mandrake's RPM)
- user creation in scriptlets done per Fedora standards

* Tue Mar 16 2010 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.5.4
- add inodes check to hobbitclient-linux.sh

* Tue Sep 01 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.5.3
- add perl to Requires due to use in hobbitclient-sar
- bugfixes in sample yum check-update script

* Mon Aug 24 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.5.2
- fix sadc version determiniation for alternate arguments
- add hobbitd_rrd.rec.patch for RH7

* Fri Jul 31 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.5.1
- apply bbcombotest patch
- re-add (unused) clientupdate man page to client-passive rpm
- bbcmd: hush when using default environment file unless in debug mode
- client: submit data from /proc/mounts along with the mount command's version
- bb: --both switch to append any STDIN after the msg on the command line
- add sysstat checks if available (in 1m intervals)
- remove sleep in hobbitclient.sh for vmstat (and sar) calls
- initscripts clean up both temp vmstat and sadc data files


* Fri Jul 17 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.4.1
- disable hobbitd_rrd caching - data loss in high channel loads
- remove superfluous "exit" in hobbitclient-sh to make easier to patch
- add xymon.do_ncv.offbyone.patch
- add hobbitgraph-ff3.5.zoom.patch

* Wed Jul 08 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.4
- add client-passive package w/o user or service files
- minor spec file cleanup
- bug in hobbit -> xymon httpd.conf rewrite rule

* Fri Jun 12 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.3
- fix perms on both server AND client logfetch tool packages
- split clientlaunch.cfg into /etc/xymon-client/launch.d/ on clients
- move pidfile for msgcache daemon on client to /var/run where it belongs
- improved README.redhat doc

* Fri Jun 12 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.2.3
- back out dependency patch pending further review, rename hobbitd to _hobbitd
  inside launch.d/ to work around
- add hobbitlaunch_newline patch for the above error condition
- leave BBTMP in place throughout, since we now differentiate between
  client and server at the environment variable level
- allow other users to execute logfetch tool, for remote execution

* Thu Jun 11 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.2.1
- bug: /var/lib/xymon/tmp (for the server) was not apache-writable;
  hobbitgraph.sh was exiting immediately
- include sample sysconfig files on server as well
- don't require dependencies in hobbitlaunch.cfg to be in any specific order

* Thu May 28 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.2
- add xymonClientRoot to client-core to prevent bbcmd errors

* Mon Apr 27 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta2-0.1
- update to beta2, remove upstreamed patches
- insert new server variable for pid location: BBRUNDIR

* Mon Apr 20 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.97.1
- add xymon.hobbitd_buflen patch

* Fri Apr 17 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.97
- remove sar files (will create separate extensions package)
- bb/bbcmd broken off into a client-core package for non-daemon installs

* Thu Apr 9 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.965
- ensure load from client-runtime.cfg file in hobbitserver.cfg
- reduce sadc report frequency from 30s to 2m

* Fri Mar 27 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.964
- bugfixes in xymon-sadc.sh
- FIXME: double-check using right /tmp directories between sadc scripts and hobbitclient-linux reader

* Fri Mar 27 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.963
- increase default MAXMSG_* to at least 512K
- add xymon-sadc.sh and xymon-sardata.sh for better sar integration on clients
- server-side script to take data reports and make status reports coming soon
- data module enabled by default on server (until rrd integration done)

* Thu Mar 26 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.962
- add bb-sar script to client (and client on server); Requires: sysstat
- ensure HOBBITCLIENTHOME is defined in hobbitclient.cfg so that bbcmd has 
  a valid environment on clients even when not being run by an init script
- redirect /hobbit in apache config instead of just /hobbit/
- if using xymon, add mod_rewrites for the older "hobbit" locations

* Wed Mar 25 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.96
- bbcmd looks in both the server and client configs for its default environment
  instead of just the server
- the client running on the server now loads /etc/sysconfig/xymon-client like
  the standalone client does (so we can report our local status to an 
  additional xymon server besides ourself)
- touch an empty hobbit-holidays.cfg file
- logfetch is now chmod 2700 (sgid) with a configurable group for 
  reading /var/log/messages (normally the 'daemon' group)

* Tue Mar 24 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.95
- switch client's tmpdir to /dev/shm to ensure it can continue to run even
  when /tmp and /var/tmp are full.
- move out unused runclient.sh and hobbit.sh scripts and replace with
  symlinks to the init scripts
- convert hobbitlaunch's config to seperate files in /etc/xymon/launch.d
- hobbitlaunch patch: ignore .rpm files
- hobbitlaunch patch: don't segfault on empty configs

* Thu Mar 05 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.92
- replace BBSERVERLOGS, BBVAR, BBTMP in server hobbitlaunch.cfg

* Wed Mar 04 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.91
- add four patches from hobbitmon list
- add lsbrelease.patch and Requires: lsb
- add README.redhat describing package changes
- per Fedora guidelines, no longer delete user/group on uninstall
- chmod perms on /var/log/messages to allow 'daemon' group to read
- client: launch pid now stored in /var/run/xymon/hobbitlaunch.pid
- server: tmpdir moved from /var/lib/xymon/tmp to /var/tmp/xymon
- server: web templates moved from /etc/xymon/web to /usr/share/xymon/web


* Tue Mar 03 2009 Japheth Cleaver <jcleaver@soe.sony.com> 4.3.0_beta1-0.6
- update package name, service name, and user/groups created
  from hobbit to xymon
- rewrite large portions of spec file for clarity
- make alternate shell configurable in the package
- tighten a few permissions throughout
- clean up vmstat files lying around upon service stop

* Wed Nov 19 2008 Japheth Cleaver <jcleaver@soe.sony.com> 4.2.0-14
- Add BuildRequires: gcc-c++

* Mon Aug 04 2008 Japheth Cleaver <cleaver@redwire.net> 4.2.0-13
- fix integer bug in relver determiniation in init scripts

* Thu Jun 05 2008 Japheth Cleaver <cleaver@redwire.net> 4.2.0-11
- make sure we exclude scripts run during install from our sh -> ash search

* Wed Mar 05 2008 Japheth Cleaver <cleaver@redwire.net> 4.2.0-10
- rebuild

* Thu Oct 12 2006 Japheth Cleaver <cleaver@redwire.net> 4.2.0-9
- print summaries on bb2 page

* Fri Oct 6 2006 Japheth Cleaver <cleaver@redwire.net> 4.2.0-8
- update to use most recent all-in-one patch
- replace all occurances of dig in bb-hosts to dns
- cleaner killing of vmstat and other processes hanging around
  after initscript: stop
- add Obsoletes for big brother

* Wed Oct 4 2006 Japheth Cleaver <cleaver@redwire.net> 4.2.0-7
- update to use most recent all-in-one patch
- use ash in more places, if package is compiled to use it
- better error given if reload attempted when server is not running

* Mon Oct 2 2006 Japheth Cleaver <cleaver@redwire.net> 4.2.0-6
- $PATH in initscripts now set by init.d/functions, with libexec added

* Thu Sep 28 2006 Japheth Cleaver <cleaver@redwire.net> 4.2.0-5
- additional released patches from distribution
- minor package cleanup

* Mon Aug 21 2006 Japheth Cleaver <cleaver@redwire.net> 4.2.0-4
- lots of patches from distribution
- initscript: runtimefile was not being created on cond restart

* Thu Aug 10 2006 Japheth Cleaver <cleaver@redwire.net> 4.2.0-1
- updated to release version


* Fri Aug 04 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.99_08041
- update to latest allinone patch
- minor cleanups

* Tue Jul 25 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.97-RC-20060712
- bugfix on cgi-secure/hobbit-enadis.sh
- modify description of main package

* Tue Jul 25 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.97-RC-20060712
- restore /var/www/hobbit/notes
- initscript: better compatibility for RH9, restore differing behavior
  for multiple HOBBITSERVERS in client-runtime.cfg, erase pids and client-runtime

* Tue Jul 25 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.95-RC-20060712
- initscript: check for FC5+ and use newer options to killproc and status
  only when available
- initscript: add client-runtime.cfg generation in hobbit server script as well
- move ext directories from libexec to /etc/hobbit{-client}/ext
- force remove of /usr/share/hobbit/client/ext dir if it exists
- use ash only per a define in package file
- bugfix: --no-pin quote fix in hobbit/hobbitcgi.cfg
- patch: "ps" display parsing: see http://www.hswn.dk/hobbiton/2006/07/msg00397.html

* Mon Jul 24 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.93-RC-20060712
- add symlinks to bb and bbcmd to hobbit-client package as well
- move ext scripts into /usr/libexecdir/hobbit{-client} with other scripts, add symlink
- Require /bin/ash instead of ash
- substitute hostname for localhost in /etc/hobbit/hobbitserver.cfg on install

* Mon Jul 24 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.8.5-RC-20060712
- update to latest allinone patch
- hardcode most paths to their FHS values at prep/build time

* Thu Jul 20 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.8.2-RC-20060712
- update to latest allinone patch
- use new fedora-specific initscripts for hobbit and hobbit-client
- make a few variables in hobbitclient.cfg more direct
  (remove references to BBHOME)
- move all pidfiles to /var/run/hobbit
- add proper man pages to hobbit-client package

* Wed Jul 19 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.8.1-RC-20060712
- update to latest allinone patch
- fix perms on logfetch in hobbit-client

* Tue Jul 18 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.7.1-RC-20060712
- update to RC-20060712 + allinone
- add httpd reload to Post scripts
- remove fping from Requires

* Tue Jun 27 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.4-beta-20060605
- add allinone patch

* Mon Jun 19 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.3-beta-20060605
- update to beta-20060605
- add httpd to Requires(pre) for server

* Fri Apr 28 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.2-alfa-20060423
- move binaries into libexec for both server and client
- move hobbit-client config files into /etc/hobbit-client
- delete hobbit user in Postun

* Fri Apr 28 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0.1-alfa-20060423
- typos in pre/preun scripts
- fix initscripts to point to /etc/sysconfig and /usr/share/hobbit

* Thu Apr 27 2006 Japheth Cleaver <cleaver@rohan.sdsu.edu> 4.2-0-alfa-20060423
- new spec file based on one included in package

